@@ -379,6 +379,10 @@ public:
 
 	static LWindow*		FindWindowByID( PaneIDT inWindowID );
 	
+	void			_HandleClick(
+					const EventRecord inMacEvent,
+					SInt16			inPart);
+
 protected:
 	WindowPtr		mMacWindowP;
 	Rect			mMinMaxSize;
@@ -393,6 +397,7 @@ protected:
 	ThemeTextColor	mInactiveTextColor;
 	mutable CGContextRef	mCGContext;
 	bool			mMoveOnlyUserZoom;
+	bool			in_redraw;
 	
 	#if PP_Uses_Carbon_Events
 		LWindowEventHandlers*	mEventHandlers;
