@@ -57,6 +57,7 @@ typedef _SEM *D_SEM;
 
 typedef struct wd_entry {
 	struct wd_entry *	next;
+	struct wd_entry *	wait_list;
 	int			fd;
 	int			state;
 #define WDS_SAME_FD_WAIT	1
@@ -67,6 +68,7 @@ typedef struct wd_entry {
 #define WDS_CP_SIGNAL		6
 	int			type;
 	HTID			htid;
+	int			ary_id;
 	int			p_events;
 	int			p_revents;
 } WD_ENTRY;
@@ -114,7 +116,6 @@ int _create_task(void (*func)(),int data,int pri);
 
 #include	"m_thread.h"
 
-void throw_signal(int tid,int sig);
 int ss_do(void (*func)(void*),void * arg);
 
 int _sem_getvalue(D_SEM s,int * value);
@@ -140,5 +141,6 @@ int
 u_child_countup();
 
 
+
 #endif
 
