@@ -35,6 +35,7 @@ void sigpipe_handler();
 void sigint_handler();
 void siglwp_handler();
 
+
 extern int task_flags;
 int pri_table[PRI_MAX] = {0,10,20,30,40,50};
 
@@ -132,6 +133,7 @@ sem_t * s;
 char name[16];
 static int sem_num;
 int i = 0;
+
 	do {
 		sprintf(name, "%d-%04i", getpid(), ++sem_num);
 		s = sem_open(name, O_CREAT | O_EXCL, 0600, 0);
@@ -154,34 +156,47 @@ _lock_task(D_SEM s,char * file,int line)
 {
 retry:
 	errno = 0;
-	if ( cmp_htid(s->tid,_get_tid()) == 0 && s->value <= 0 )
-		er_panic("double lock?");
+	if ( s->trace_bit ) {
+		if ( cmp_htid(s->tid,_get_tid()) == 0 && s->value <= 0 )
+			er_panic("double lock?");
+	}
 	if ( sem_wait(s->s) ) {
 		if ( errno == EINTR )
 			goto retry;
 	}
-	s->tid = _get_tid();
-	s->value--;
+
+	if ( s->trace_bit ) {
+		s->tid = _get_tid();
+		s->value--;
+		s->lock_htid = s->tid;
+	}
+
 	s->lock_file = file;
 	s->lock_line = line;
-	s->lock_htid = _get_tid();
+
+
 }
 
 void
 _unlock_task(D_SEM s,char *str,char * file,int line)
 {
-	s->tid = invalid_htid();
-	s->value++;
+
+	if ( s->trace_bit ) {
+		s->tid = invalid_htid();
+		s->value++;
+		s->unlock_htid = _get_tid();
+	}
 	s->unlock_file = file;
 	s->unlock_line = line;
-	s->unlock_htid = _get_tid();
+
 	for ( ; sem_post(s->s); );
 }
 
 void xx_close_lock(D_SEM s)
 {
 sem_nos --;
-	sem_destroy(s->s);
+	sem_close(s->s);
+//	sem_destroy(s->s);
 	free_block(s);
 }
 
@@ -192,10 +207,17 @@ D_SEM s;
 	s = new_block();
 	s->s = new_semaphore();
 	s->value = 1;
+	s->trace_bit = 0;
 sem_nos ++;
 	return s;
 }
 
+void
+set_trace_bit(SEM s)
+{
+	s.so->d_sem->trace_bit = 1;
+}
+
 int
 _sem_getvalue(D_SEM s,int * value)
 {
