@@ -27,10 +27,18 @@ u_stat(char * path,U_STAT * buf)
 int ret;
 struct stat64_t _buf;
 char * _path;
+int eno;
+
+	if ( path == 0 )
+		return -1; 
 	_path = change_delim_str(path);
+	if ( _path ==  0 )
+	  return -1;
 	ret = _stat64(_path,&_buf);
-	if ( _path != path )
+	eno = errno;
+	if ( (_path != path) )
 		d_f_ree(_path);
+	errno = eno;
 	if ( ret < 0 )
 		return ret;
 	buf->us_mtime = 
