@@ -28,6 +28,13 @@ change_endian_gb_point(GB_POINT * p)
 }
 
 
+void
+change_endian_gb_point_f(GB_POINT_F * p)
+{
+	change_endian_f(p->x);
+	change_endian_f(p->y);
+}
+
 
 void
 change_endian_gb_rect(GB_RECT * r)
@@ -36,6 +43,13 @@ change_endian_gb_rect(GB_RECT * r)
 	change_endian_gb_point(&r->br);
 }
 
+void
+change_endian_gb_rect_f(GB_RECT_F * r)
+{
+	change_endian_gb_point_f(&r->tl);
+	change_endian_gb_point_f(&r->br);
+}
+
 void
 change_endian_gb_color(GB_COLOR * c)
 {
