@@ -18,6 +18,7 @@
 
 
 #include	"gbgraph.h"
+#include	"memory_debug.h"
 
 
 //char day_ary[8][5] = {
@@ -45,12 +46,14 @@ set_format(char * buf,char d)
 void
 gb_time_format(char * ret,GB_TIME * t)
 {
-char year[100];
+char * year;
 char month[10];
 char date[10];
 char hour[10];
 char min[10];
 char sec[10];
+
+	year = d_alloc(10000);
 	if ( t->year == 0 )
 		sprintf(year,"*");
 	else if ( t->year == (int)t->year )
@@ -65,5 +68,6 @@ char sec[10];
 		t->day = 7;
 	sprintf(ret,"%s-%s-%s.%s.%s:%s:%s",
 			year,month,date,day_ary[(int)t->day],hour,min,sec);
+	d_f_ree(year);
 }
 
