@@ -149,6 +149,7 @@ int ret;
 VIEW_METHOD ** rp,*r;
 int same_flag;
 MATRIX * m;
+int i;
 	if ( vmt == 0 )
 		return 0;
 	m = res->h.mtx;
@@ -171,9 +172,29 @@ MATRIX * m;
 		vmt1 = vmt;
 		same_flag = 0;
 	retry:
-		for ( ; *vmt1 ; vmt1 ++ )
-			if ( (*vmt1)->mdt_type == type )
+		for ( ; *vmt1 ; vmt1 ++ ) {
+			if ( (*vmt1)->mdt_type != type )
+				continue;
+			if ( (*vmt1)->dimension == -1 )
 				break;
+			if ( (*vmt1)->dimension != m->p.dim )
+				continue;
+			if ( (*vmt1)->divide == 0 )
+				break;
+			for ( i = 0 ; i < m->p.dim ; i ++ ) {
+				if ( (*vmt1)->divide[i] == -1 )
+					continue;
+				if ( (*vmt1)->divide[i] == -2 ) {
+					if ( m->dim_divide[i] == 0 )
+						goto diff;
+				}
+				else if ( (*vmt1)->divide[i] != m->dim_divide[i] )
+					goto diff;
+			}
+			break;
+		diff:
+			;
+		}
 		if ( *vmt1 == 0 ) {
 			if ( vmt_same == 0 || same_flag )
 				continue;
@@ -273,6 +294,8 @@ int i;
 
 
 	filename = get_filepath_from_file_id(r->h.cache_file_id,".mtx");
+	if ( filename == 0 )
+		goto next;
 	m = open_matrix(0,filename,0,0,0);
 	if ( m == 0 )
 		goto next;
@@ -358,7 +381,8 @@ next:
 	t->token = 0;
 	t->h.pri = 0;
 	t->h.key = get_server_key(&r->h.target,0);
-	d_f_ree(filename);
+	if ( filename )
+		d_f_ree(filename);
 	return insert_queue(&res_matrix_before,t,w_flag);
 }
 
@@ -784,7 +808,7 @@ extern int spiral_count;
 		_exec_dirty(1);
 		return 0;
 	case TRT_FINISH:
-ss_printf("FINISH\n");
+//ss_printf("FINISH\n");
 		_exec_dirty(1);
 		return 0;
 	case TRT_TOKEN:
