@@ -30,6 +30,8 @@
 #include	"lump.h"
 #include	"xl.h"
 
+//#define PMD_DEBUG
+
 int
 lock_db(PMD_WORK * w)
 {
@@ -71,7 +73,7 @@ change_endian_pmd_header(PN_PMD_HEADER * h)
 }
 
 void
-change_endian_pmd_node(PN_PMD_NODE * n)
+change_endian_pmd_node_to_host(PN_PMD_NODE * n)
 {
 	change_endian_header(&n->h);
 	change_endian_gb_rect(&n->minrect);
@@ -83,9 +85,26 @@ change_endian_pmd_node(PN_PMD_NODE * n)
 	change_endian_s(n->category);
 	change_endian_s(n->target);
 	change_endian_l_char(n->str);
+	change_endian_l_char(&n->str[n->target]);
 }
 
 
+void
+change_endian_pmd_node_to_net(PN_PMD_NODE * n)
+{
+	change_endian_header(&n->h);
+	change_endian_gb_rect(&n->minrect);
+	change_endian_f(n->resolution);
+	change_endian_gb_time(&n->content_period_from);
+	change_endian_gb_time(&n->content_period_to);
+	change_endian_i(n->timeout);
+	change_endian_i(n->md_fofs);
+	change_endian_s(n->category);
+	change_endian_l_char(n->str);
+	change_endian_l_char(&n->str[n->target]);
+	change_endian_s(n->target);
+}
+
 void
 change_endian_pmd_md(PN_PMD_MD * md)
 {
@@ -122,16 +141,29 @@ int n,i;
 int
 cmp_floating(FLOATING_INDEX * f1,FLOATING_INDEX * f2)
 {
+REAL1 d1,d2;
+	memcpy(&d1,f1+1,sizeof(d1));
+	memcpy(&d2,f2+1,sizeof(d2));
+	if ( d1 < d2 )
+		return -1;
+	if ( d1 > d2 )
+		return 1;
+	return 0;
+
+/*
 	if ( f1->d < f2->d )
 		return -1;
 	if ( f1->d > f2->d )
 		return 1;
+*/
+
 	return 0;
 }
 
 int
 cmp_timeout(TIMEOUT_INDEX * ix1,TIMEOUT_INDEX * ix2)
 {
+
 	if ( ix1->timeout < ix2->timeout )
 		return -1;
 	if ( ix1->timeout > ix2->timeout )
@@ -147,6 +179,7 @@ L_CHAR * encoding;
 ACC_PN_PMD_HEADER * h;
 FAVT_ROOT * rt;
 int ret;
+
 	encoding = l_string(std_cm,"UCS4");
 	p = open_filespace(
 		path,O_CREAT|O_RDWR|O_TRUNC,0644,
@@ -249,6 +282,7 @@ unsigned int fofs;
 char * pp;
 int err;
 
+
 	w->err = 0;
 	w->path = 0;
 	w->p = 0;
@@ -262,7 +296,7 @@ retry:
 		w->path,mode,
 		0644,PF_USEFREELIST,FT_ADDRESS_LUMP,0,0,0);
 	if ( w->p == 0 ) {
-		err = errno;
+		err = ufr_errno;
 		log_printf(LOG_SYSTEM,LOG_LAYER_GB,0,
 "remake lump (%s:%s:%x) because open error (err=%i:(%i:%i):fs-%i:pdb-%i:u-%i:ufr-%i)",
 			n_string(std_cm,db),
@@ -284,6 +318,7 @@ retry:
 		log_printf(LOG_SYSTEM,LOG_LAYER_GB,0,
 			"remake lump2 %i",err);
 	remake:
+
 		if ( unit_path == 0 ) {
 			w->err = -10;
 			return;
@@ -320,8 +355,13 @@ retry:
 			free_pmd_work(w);
 			w->path = pp;
 			log_printf(LOG_SYSTEM,LOG_LAYER_GB,0,
-	"remake lump (%s) because incomplete write/invalid version/invalid unit",
-				n_string(std_cm,db));
+	"remake lump (%s) because incomplete write(%x)/invalid version(%s:%s)/invalid unit(%s:%s)",
+				n_string(std_cm,db),
+				(int)w->pmd_h.d.flags,
+				w->pmd_h.d.version,PMD_VERSION,
+				(w->pmd_h.d.unit_path ? n_string(std_cm,w->pmd_h.d.unit_path) : "[null]"),
+				(unit_path ? n_string(std_cm,unit_path) : "[null]")
+				);
 			goto remake;
 		}
 	}
@@ -379,6 +419,8 @@ ACC_PN_PMD_MD * md;
 	ret = 0;
 	for ( ; fofs ; ) {
 		md = read_filespace(w->p,fofs);
+		if ( md == 0 )
+			return 0;
 		change_endian_pmd_md(&md->d);
 		if ( md->d.h.type != PNT_PMD_MD ) {
 			free_bib_list(ret);
@@ -408,7 +450,7 @@ PMD_TEMP * ret;
 	n = read_filespace(w->p,fofs);
 	if ( n == 0 )
 		return 0;
-	change_endian_pmd_node(&n->d);
+	change_endian_pmd_node_to_host(&n->d);
 	if ( n->d.h.type != PNT_PMD_NODE ) {
 		d_f_ree(n);
 		return 0;
@@ -449,22 +491,28 @@ int ret;
 			if ( w3c_dtf_to_gb_time(from,buf) < 0 ) {
 				if ( w3c_dtf_to_gb_time(to,ptr) < 0 )
 					goto end;
-				from->year = FLT_MIN;
+				*from = *to;
+				from->year = to->year-100;
+/*
 				from->month = -1;
 				from->date = -1;
 				from->day = -1;
 				from->hour = -1;
 				from->min = -1;
 				from->sec = -1;
+*/
 			}
 			else if ( w3c_dtf_to_gb_time(to,ptr) < 0 ) {
-				to->year = FLT_MAX;
+				*to = *from;
+				to->year = from->year + 100;
+/*
 				to->month = -1;
 				to->date = -1;
 				to->day = -1;
 				to->hour = -1;
 				to->min = -1;
 				to->sec = -1;
+*/
 			}
 			ret = 0;
 			goto end;
@@ -507,6 +555,7 @@ PMD_TEMP * ret;
 	if ( r->h.bib == 0 )
 		return 0; 
 	ret = d_alloc(sizeof(*ret));
+	memset(ret,0,sizeof(*ret));
 	ret->fofs = 0;
 	ret->minrect = *minrect;
 	ret->resolution = resolution;
@@ -615,7 +664,7 @@ ACC_PN_PMD_NODE * n;
 	n = read_filespace(w->p,fofs);
 	if ( n == 0 )
 		return;
-	change_endian_pmd_node(&n->d);
+	change_endian_pmd_node_to_host(&n->d);
 	free_pmd_md(w,n->d.md_fofs);
 	free_filespace(w->p,fofs);
 	d_f_ree(n);
@@ -633,8 +682,7 @@ unsigned int fofs;
 	crd_len = l_strlen(t->crd);
 	target_len = l_strlen(t->target);
 	n = d_alloc(PN_PMD_NODE_S(crd_len,target_len)
-		+ sizeof(ACC_HEADER));
-
+		+ sizeof(ACC_HEADER)+8);
 	switch ( type ) {
 	case WRITE_TEMP_ALLOC:
 		t->md_fofs = alloc_bib_list(w,t->md_list);
@@ -666,7 +714,7 @@ unsigned int fofs;
 	default:
 		er_panic("write_temp(2)");
 	}
-	change_endian_pmd_node(&n->d);
+	change_endian_pmd_node_to_net(&n->d);
 	write_filespace(w->p,n);
 	fofs = t->fofs;
 	d_f_ree(n);
@@ -711,6 +759,7 @@ STRING_INDEX * ix;
 int crd_len,obj_len;
 FAVT_NODE * n, *nn;
 FAVT_ROOT * r;
+
 	r = get_root(&w->favt_err,
 		w->p,w->pmd_h.d.ix_target,favt_string_endian);
 	if ( r == 0 ) {
@@ -747,6 +796,8 @@ STRING_INDEX * ix;
 int crd_len,obj_len;
 FAVT_NODE * n;
 FAVT_ROOT * r;
+
+
 	r = get_root(&w->favt_err,
 		w->p,w->pmd_h.d.ix_target,favt_string_endian);
 	if ( r == 0 ) {
@@ -1011,6 +1062,7 @@ insert_db(PMD_WORK * w,PMD_TEMP * t)
 {
 int er;
 
+
 	w->err = 0;
 	write_temp(w,t,WRITE_TEMP_ALLOC);
 	er = insert_ix(w,
@@ -1030,7 +1082,7 @@ int er;
 		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
-		return -1;
+		return -2;
 	er = insert_ix(w,
 		w->pmd_h.d.ix_br_x,
 		&t->minrect.br.x,
@@ -1039,7 +1091,7 @@ int er;
 		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
-		return -1;
+		return -3;
 	er = insert_ix(w,
 		w->pmd_h.d.ix_br_y,
 		&t->minrect.br.y,
@@ -1048,7 +1100,7 @@ int er;
 		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
-		return -1;
+		return -4;
 	er = insert_ix(w,
 		w->pmd_h.d.ix_resolution,
 		&t->resolution,
@@ -1057,7 +1109,7 @@ int er;
 		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
-		return -1;
+		return -5;
 	er = insert_ix(w,
 		w->pmd_h.d.ix_content_period_from,
 		&t->content_period_from,
@@ -1066,7 +1118,7 @@ int er;
 		favt_gb_time_endian,
 		cmp_gb_time);
 	if ( er < 0 )
-		return -1;
+		return -6;
 	er = insert_ix(w,
 		w->pmd_h.d.ix_content_period_to,
 		&t->content_period_to,
@@ -1075,7 +1127,7 @@ int er;
 		favt_gb_time_endian,
 		cmp_gb_time);
 	if ( er < 0 )
-		return -1;
+		return -7;
 	er = insert_ix(w,
 		w->pmd_h.d.ix_timeout,
 		&t->timeout,
@@ -1084,13 +1136,13 @@ int er;
 		favt_timeout_endian,
 		cmp_timeout);
 	if ( er < 0 )
-		return -1;
+		return -8;
 	er = insert_db_target(w,
 		t->crd,
 		t->target,
 		t->fofs);
 	if ( er < 0 )
-		return -1;
+		return -9;
 	return 0;
 }
 
@@ -1099,6 +1151,8 @@ int
 delete_db(PMD_WORK * w,PMD_TEMP * t)
 {
 int er;
+
+
 	w->err = 0;
 	er = delete_ix(w,
 		w->pmd_h.d.ix_tl_x,
@@ -1117,7 +1171,7 @@ int er;
 		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
-		return -1;
+		return -2;
 	er = delete_ix(w,
 		w->pmd_h.d.ix_br_x,
 		&t->minrect.br.x,
@@ -1126,7 +1180,7 @@ int er;
 		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
-		return -1;
+		return -3;
 	er = delete_ix(w,
 		w->pmd_h.d.ix_br_y,
 		&t->minrect.br.y,
@@ -1135,7 +1189,7 @@ int er;
 		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
-		return -1;
+		return -4;
 	er = delete_ix(w,
 		w->pmd_h.d.ix_resolution,
 		&t->resolution,
@@ -1144,7 +1198,7 @@ int er;
 		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
-		return -1;
+		return -5;
 	er = delete_ix(w,
 		w->pmd_h.d.ix_content_period_from,
 		&t->content_period_from,
@@ -1153,7 +1207,7 @@ int er;
 		favt_gb_time_endian,
 		cmp_gb_time);
 	if ( er < 0 )
-		return -1;
+		return -6;
 	er = delete_ix(w,
 		w->pmd_h.d.ix_content_period_to,
 		&t->content_period_to,
@@ -1162,7 +1216,7 @@ int er;
 		favt_gb_time_endian,
 		cmp_gb_time);
 	if ( er < 0 )
-		return -1;
+		return -7;
 	er = delete_ix(w,
 		w->pmd_h.d.ix_timeout,
 		&t->timeout,
@@ -1171,12 +1225,12 @@ int er;
 		favt_timeout_endian,
 		cmp_timeout);
 	if ( er < 0 )
-		return -1;
+		return -8;
 	er = delete_db_target(w,
 		t->crd,
 		t->target);
 	if ( er < 0 )
-		return -1;
+		return -9;
 	free_pmd_node(w,t->fofs);
 	return 0;
 }
@@ -1222,6 +1276,7 @@ maxmin_floating(PMD_WORK * w,REAL1 * min,REAL1 * max,unsigned int root)
 {
 FLOATING_INDEX * f;
 int d_len;
+
 	f = maxmin_ix(
 		&d_len,
 		w,
@@ -1230,7 +1285,7 @@ int d_len;
 		favt_trace_from_small);
 	if ( f == 0 )
 		return -1;
-	*min = f->d;
+	memcpy(min,f+1,sizeof(*min));
 	d_f_ree(f);
 	f = maxmin_ix(
 		&d_len,
@@ -1239,8 +1294,8 @@ int d_len;
 		favt_floating_endian,
 		favt_trace_from_large);
 	if ( f == 0 )
-		return -1;
-	*max = f->d;
+		return -2;
+	memcpy(max,f+1,sizeof(*max));
 	d_f_ree(f);
 	return 0;
 }
@@ -1260,7 +1315,8 @@ int d_len;
 		favt_trace_from_small);
 	if ( f == 0 )
 		return -1;
-	*min = f->d;
+//	*min = f->d;
+	memcpy(min,f+1,sizeof(*min));
 	d_f_ree(f);
 	f = maxmin_ix(
 		&d_len,
@@ -1270,39 +1326,81 @@ int d_len;
 		favt_trace_from_large);
 	if ( f == 0 )
 		return -1;
-	*max = f->d;
+//	*max = f->d;
+	memcpy(max,f+1,sizeof(*max));
 	d_f_ree(f);
 	return 0;
 }
 
-void
+int
 get_db_status(PMD_WORK * w,PMD_TEMP * min,PMD_TEMP * max)
 {
-	maxmin_floating(w,
+int er;
+int err_pos;
+	er = maxmin_floating(w,
 		&min->minrect.tl.x,
 		&max->minrect.tl.x,
 		w->pmd_h.d.ix_tl_x);
-	maxmin_floating(w,
+	if ( er < 0 ) {
+		if ( er == -1 )
+			err_pos = -1;
+		else	err_pos = -2;
+		goto err1;
+	}
+	er = maxmin_floating(w,
 		&min->minrect.tl.y,
 		&max->minrect.tl.y,
 		w->pmd_h.d.ix_tl_y);
-	maxmin_floating(w,
+	if ( er < 0 ) {
+		if ( er == -1 )
+			err_pos = -3;
+		else	err_pos = -4;
+		goto err1;
+	}
+	er = maxmin_floating(w,
 		&min->minrect.br.x,
 		&max->minrect.br.x,
 		w->pmd_h.d.ix_br_x);
-	maxmin_floating(w,
+	if ( er < 0 ) {
+		if ( er == -1 )
+			err_pos = -5;
+		else	err_pos = -6;
+		goto err1;
+	}
+	er = maxmin_floating(w,
 		&min->minrect.br.y,
 		&max->minrect.br.y,
 		w->pmd_h.d.ix_br_y);
-	maxmin_floating(w,
+	if ( er < 0 ) {
+		if ( er == -1 )
+			err_pos = -7;
+		else	err_pos = -8;
+		goto err1;
+	}
+	er = maxmin_floating(w,
 		&min->resolution,
 		&max->resolution,
 		w->pmd_h.d.ix_resolution);
-	maxmin_content_period(w,
+	if ( er < 0 ) {
+		if ( er == -1 )
+			err_pos = -9;
+		else	err_pos = -10;
+		goto err1;
+	}
+	er = maxmin_content_period(w,
 		&min->content_period_from,
 		&max->content_period_from,
 		w->pmd_h.d.ix_content_period_from,
 		w->pmd_h.d.ix_content_period_to);
+	if ( er < 0 ) {
+		if ( er == -1 )
+			err_pos = -11;
+		else	err_pos = -12;
+		goto err1;
+	}
+	return 0;
+err1:
+	return err_pos;
 }
 
 
@@ -1313,12 +1411,31 @@ insert_pmd_temp_list(PMD_WORK * w,PMD_TEMP_LIST * tl,unsigned int fofs,
 PMD_TEMP * t;
 PMD_TEMP_LIST * ret;
 	t = get_temp_db(w,fofs);
+#ifdef PMD_DEBUG
+ss_printf("INSERT_PMD_TEMP_LIST %ls\n",t->crd);
+ss_printf(">> %f %f - %f %f / %f %f - %f %f\n",
+t->minrect.tl.x,
+t->minrect.tl.y,
+t->minrect.br.x,
+t->minrect.br.y,
+r->tl.x,
+r->tl.y,
+r->br.x,
+r->br.y
+);
+#endif
 	if ( t == 0 )
 		return tl;
 	if ( r && cross_rect_rect(&t->minrect,r) == 0 ) {
+#ifdef PMD_DEBUG
+ss_printf("out of bound\n");
+#endif
 		free_temp(t);
 		return tl;
 	}
+#ifdef PMD_DEBUG
+ss_printf("OK\n");
+#endif
 	ret = d_alloc(sizeof(*ret));
 	ret->next = tl;
 	ret->temp = t;
@@ -1334,7 +1451,7 @@ query_db(PMD_WORK * 	w,
 {
 BOUND_LIST * b, * bb;
 FAVT_ROOT * r;
-FLOATING_INDEX ix_min,ix_max;
+FLOATING_INDEX_BUFFER ix_min,ix_max;
 FLOATING_INDEX * ixp;
 ACC_PN_PMD_OFSLIST * ol;
 int len;
@@ -1344,8 +1461,12 @@ PMD_TEMP_LIST * ret;
 		w->p,w->pmd_h.d.ix_resolution,favt_floating_endian);
 	if ( r == 0 )
 		return 0;
+/*
 	ix_min.d = reso_min;
 	ix_max.d = reso_max;
+*/
+	memcpy((&ix_min.fi)+1,&reso_min,sizeof(reso_min));
+	memcpy((&ix_max.fi)+1,&reso_max,sizeof(reso_max));
 	b = favt_bound_search(&w->favt_err,r,root_node(&w->favt_err,r),
 		&ix_min,&ix_max,cmp_floating);
 	ret = 0;
@@ -1435,4 +1556,29 @@ tl->temp->target);
 	free_pmd_temp_list(ret);
 }
 
+void
+print_pmd_temp(PMD_TEMP * t,char * msg)
+{
+char buffer[10000];
+	if ( t == 0 )
+		return; 
+	ss_printf("PMD_TEMP %s\n",msg);
+	ss_printf("\tfofs = %u\n",t->fofs);
+	ss_printf("\tminrect = %f %f - %f %f\n",
+		t->minrect.tl.x,
+		t->minrect.tl.y,
+		t->minrect.br.x,
+		t->minrect.br.y);
+	ss_printf("\tresolution = %f\n",t->resolution);
+	gb_time_format(buffer,&t->content_period_from);
+	ss_printf("\tcontent_period_from = %s\n",buffer);
+	gb_time_format(buffer,&t->content_period_to);
+	ss_printf("\tcontent_period_to = %s\n",buffer);
+	ss_printf("\ttimeout = %u (%u)\n",t->timeout,get_xltime());
+	ss_printf("\tmd_fofs = %u %p\n",t->md_fofs,t->md_list);
+	ss_printf("\tcategory = %i\n",t->category);
+	ss_printf("\tcrd = %ls\n",t->crd);
+	ss_printf("\ttarget = %ls\n",t->target);
+}
+
 
