@@ -1020,11 +1020,17 @@ int
 rs_exist_check(int fid)
 {
 L_CHAR * filepath;
+char * _filepath;
+char * __filepath;
 int fd;
 	filepath = get_filepath_from_file_id(fid,".inf");
 	if ( filepath == 0 )
 		return -1;
-	fd = u_open(n_string(std_cm,filepath),O_RDONLY);
+	__filepath = change_delim_str(_filepath=n_string(std_cm,filepath));
+	fd = u_open(__filepath,O_RDONLY);
+	if ( __filepath != _filepath )
+		d_f_ree(__filepath);
+	d_f_ree(filepath);
 	if ( fd < 0 )
 		return -1;
 	u_close(fd);
@@ -1863,7 +1869,6 @@ int i;
 		ret->pr64.height[i] = r64->height[i];
 	}
 	ret->pr64.max_level = r64->max_level;
-ss_printf("LOAD LST-1\n");
 	gv_new_luster_option(ret,ret->pr64.max_level);
 	return ret;
 }
@@ -2568,7 +2573,12 @@ STREAM * st;
 XL_SEXP * ret, * p, * load;
 int _ret;
 void gc_gb_sexp();
-	st = s_open_file(n_string(std_cm,filepath),O_RDONLY);
+char * _filepath;
+char * __filepath;
+	__filepath = change_delim_str(_filepath=n_string(std_cm,filepath));
+	st = s_open_file(__filepath,O_RDONLY);
+	if ( __filepath != _filepath )
+			d_f_ree(__filepath);
 	if ( st == 0 )
 		return -1;
 	s_set_cm(st,&extucs4_cm);
@@ -2596,7 +2606,12 @@ int
 _set_rs_str(L_CHAR * filepath,XL_SEXP * s)
 {
 STREAM * st;
-	st = s_open_file(n_string(std_cm,filepath),O_CREAT|O_TRUNC|O_RDWR,0644);
+char * __filepath;
+char * _filepath;
+	__filepath = change_delim_str(_filepath=n_string(std_cm,filepath));
+	st = s_open_file(__filepath,O_CREAT|O_TRUNC|O_RDWR,0644);
+	if ( __filepath != _filepath )
+			d_f_ree(__filepath);
 	if ( st == 0 )
 		return -1;
 	s_set_cm(st,&extucs4_cm);
@@ -2679,6 +2694,10 @@ flush_rs_cache()
 void
 _disable_rs_cache()
 {
+	if ( resource_cache.path == 0 )
+		return;
+	if ( resource_cache.backup == 0 )
+		return;
 	_close_rs_cache();
 	resource_cache.err = RE_IDLE;
 	flush_general_lock(&resource_cache);
