@@ -60,6 +60,7 @@ double GRS80_param[2] = 	{6378.137,6356.752};
 
 GEO_TYPE_TBL gt_topology[] = {
 	{"2d" , GT_T_2D,0},
+	{"1d" , GT_T_1D,0},
 	{"globe-sur" , GT_T_GLOBE_SUR,0},
 	{"",0,0}
 };
@@ -83,6 +84,7 @@ GEO_TYPE_TBL gt_axis[] = {
 
 GT_MACRO_TBL gt_macro[] = {
 	{"e2d", GT_E2D,0,GT_A_COMP},
+	{"e1d", GT_E1D,0,GT_A_COMP},
 	{"everest-1830",	GT_ELLIPSOID,	everest_1830_param,GT_A_MATH},
 	{"bessel-1841",		GT_ELLIPSOID,	bessel_1841_param,GT_A_MATH},
 	{"airy-1849",		GT_ELLIPSOID,	airy_1849_param,GT_A_MATH},
@@ -433,6 +435,7 @@ L_CHAR * unit;
 MAP * m, * m1;
 URL url_buf;
 unsigned int index_time;
+int ls_assert_flag = 0;
 
 /*
 ss_printf("===================== ???\n");
@@ -548,7 +551,7 @@ m1->cindex_mr.br.y
 		INSERT_RING(&m->h,&m1->h);
 /***/
 		unlock_task(res_lock,"write_lock");
-		load_coordinate_option();
+		ls_assert_flag = 1;
 	next:
 		{}
 	}
@@ -558,6 +561,8 @@ m1->cindex_mr.br.y
 			m = R_NEXT(MAP*,&m->h) ) {
 		m->cindex_time = index_time;
 	}
+	if ( ls_assert_flag )
+		load_coordinate_option(r);
 }
 
 void
@@ -625,7 +630,7 @@ URL url_buf;
 
 		unlock_task(res_lock,"write_");
 
-		load_coordinate_option();
+		load_coordinate_option(r);
 	next:
 		{}
 	}
