@@ -712,7 +712,8 @@ rct.br.y);
 	end:
 
 		unlock_pdb_lock(r);
-/*
+/*dgb_mark.c
+
 		if ( test_pdb_err_sensitive(r) )
 			break;
 */
@@ -745,7 +746,9 @@ int ret;
 	ret = check_default(r,chk);
 	if ( ret != 0 )
 		return ret;
-	chk->opt[r->h.type] |= r->draw_gb.flags;
+	if ( r->draw_gb.flags == 0 )
+		chk->opt[r->h.type] |= DGF_POLY|DGF_INFO;
+	else	chk->opt[r->h.type] |= r->draw_gb.flags;
 	return 0;
 }
 
