@@ -66,6 +66,9 @@ struct {
 	int		initial_warp_method;
 	L_CHAR *	gateway_server;
 	int		gateway_port;
+	
+	unsigned	draw_map_flag:1;
+	unsigned	hwf:1;
 } view_param;
 
 
@@ -453,6 +456,79 @@ XL_SEXP * _routing, * _resource;
 }
 
 
+int
+set_draw_mapping(int d,int save_flag)
+{
+	switch ( d ) {
+	case 0:
+		view_param.draw_map_flag = 0;
+		view_param.write_flag = 1;
+		break;
+	case 1:
+		view_param.draw_map_flag = 1;
+		view_param.write_flag = 1;
+	}
+	if ( save_flag )
+		xl_write_status(0,0);
+	return view_param.draw_map_flag;
+}
+
+XL_SEXP *
+xl_draw_mapping(XLISP_ENV * env,XL_SEXP * s,XLISP_ENV * a,XL_SYM_FIELD * sf)
+{
+XL_SEXP * d;
+	d = get_el(s,1);
+	if ( get_type(d) != XLT_INTEGER )
+		goto typemissmatch;
+	return get_integer(set_draw_mapping(d->integer.data,0),0);
+typemissmatch:
+	return get_error(
+		s->h.file,
+		s->h.line,
+		XLE_SEMANTICS_TYPE_MISSMATCH,
+		l_string(std_cm,"draw-mapping"),
+		list(	n_get_string(
+		"type missmatch"),
+			0));
+}
+
+
+int
+set_hwf(int d,int save_flag)
+{
+	switch ( d ) {
+	case 0:
+		view_param.hwf = 0;
+		view_param.write_flag = 1;
+		break;
+	case 1:
+		view_param.hwf = 1;
+		view_param.write_flag = 1;
+	}
+	if ( save_flag )
+		xl_write_status(0,0);
+	return view_param.hwf;
+}
+
+XL_SEXP *
+xl_hwf(XLISP_ENV * env,XL_SEXP * s,XLISP_ENV * a,XL_SYM_FIELD * sf)
+{
+XL_SEXP * d;
+	d = get_el(s,1);
+	if ( get_type(d) != XLT_INTEGER )
+		goto typemissmatch;
+	return get_integer(set_hwf(d->integer.data,0),0);
+typemissmatch:
+	return get_error(
+		s->h.file,
+		s->h.line,
+		XLE_SEMANTICS_TYPE_MISSMATCH,
+		l_string(std_cm,"hwf"),
+		list(	n_get_string(
+		"type missmatch"),
+			0));
+}
+
 XL_SEXP *
 xl_status_param(XLISP_ENV * env,XL_SEXP * s)
 {
@@ -624,8 +700,9 @@ STREAM * st;
 		view_param.width,view_param.height);
 	s_printf(st,"<lang> %ls </lang>\n",
 		view_param.lang);
-	s_printf(st,"<theme> ^\"%ls\" </theme>\n",
-		view_param.theme);
+	if ( view_param.theme )
+		s_printf(st,"<theme> ^\"%ls\" </theme>\n",
+			view_param.theme);
 /*
 	s_printf(st,"<http-client>%s </http-client>\n",http_client);
 */
@@ -634,12 +711,18 @@ STREAM * st;
 	s_printf(st,"<default-conditions>\n");
 	print_sexp(st,view_param.default_conditions,PF_XML|PF_INDENT);
 	s_printf(st,"\n</default-conditions>\n");
-	s_printf(st,"<start-point-URL> %ls </start-point-URL>\n",view_param.start_point_URL);
-	if ( view_param.gateway_server[0] == 0 )
+	if ( view_param.start_point_URL )
+		s_printf(st,"<start-point-URL> %ls </start-point-URL>\n",view_param.start_point_URL);
+	if ( view_param.gateway_server == 0 )
+		s_printf(st,"<gateway> ^\"\" 0 </gateway>\n",
+			view_param.gateway_port);
+	else if ( view_param.gateway_server[0] == 0 )
 		s_printf(st,"<gateway> ^\"\" %i </gateway>\n",
 			view_param.gateway_port);
 	else	s_printf(st,"<gateway> %ls %i </gateway>\n",view_param.gateway_server,
 			view_param.gateway_port);
+	s_printf(st,"<draw-mapping> %i </draw-mapping>\n",view_param.draw_map_flag);
+	s_printf(st,"<hwf> %i </hwf>\n",view_param.hwf);
 
 	s_printf(st,"</gv-resource>\n\n");
 
@@ -708,6 +791,13 @@ XLISP_ENV * e,* top_e;
 	set_env(e,l_string(std_cm,"gv-reset-status"),
 		get_func_prim(xl_reset_status,
 			FO_APPLICATIVE,0,1,1));
+	set_env(e,l_string(std_cm,"draw-mapping"),
+			get_func_prim(xl_draw_mapping,
+			FO_APPLICATIVE,0,2,2));
+	set_env(e,l_string(std_cm,"hwf"),
+			get_func_prim(xl_hwf,
+			FO_APPLICATIVE,0,2,2));
+
 
 	set_env(e,l_string(std_cm,"gv-set-cache"),
 		get_func_prim(xl_set_cache,
@@ -1051,6 +1141,7 @@ char * file;
 int pid;
 L_CHAR * parameter = 0, * peripheral = 0;
 	
+	gc_push(0,0,"loading_file");
 	if ( parameter1 )
 		parameter = ll_copy_str(parameter1);
 	if ( peripheral1 )
@@ -1075,5 +1166,6 @@ L_CHAR * parameter = 0, * peripheral = 0;
 		d_f_ree(parameter);
 	if ( peripheral )
 		d_f_ree(peripheral);
+	gc_pop(0,0);
 }
 
