@@ -35,17 +35,25 @@
 #define STRING_RECT_OFFSET		1
 #define STRING_ALL_PRINT		5
 
+int
+setup_view_methods(RESOURCE * res,MATRIX_NODE * n,VIEW_METHOD_TBL ** vmt,VIEW_METHOD ** vm);
+
 /*********************************************************
 	PLOT DRAW
 **********************************************************/
 
+extern SEM res_lock;
+
 int
 vmt_create_plot(VIEW_METHOD*,MATRIX_NODE*);
 void
 vmt_draw_plot(VIEW_METHOD*,GBVIEW_FLAME*,RESOURCE *,DRAW_WORK*);
 
+static int div_list[] = {-2,-2};
+
 VIEW_METHOD_TBL vm_plot_tbl = {
-	MDT_BLOCK,&blk_pp_tbl,
+	MDT_BLOCK,
+	2,div_list,&blk_pp_tbl,
 	vmt_create_plot,
 	0,
 	vmt_draw_plot,
@@ -134,7 +142,6 @@ init_pg_vector(XLISP_ENV * env)
 XLISP_ENV * pgv_env;
 XLISP_ENV * run_env;
 
-ss_printf("INIT pg_vector\n");
 	pgv_env = new_env(env);
 	root_tag(env,l_string(std_cm,"pg-vector"),pgv_env);
 	set_env(pgv_env,l_string(std_cm,"mark"),
@@ -697,7 +704,7 @@ VM_PLOT * vmp;
 }
 
 void
-set_search_parameter(MATRIX * m,INTEGER64 * start,INTEGER64 * end,INTEGER64 * inc,GB_RECT rct,int lev)
+set_search_parameter(MATRIX * m,INTEGER64 * start,INTEGER64 * end,INTEGER64 * inc,GB_RECT rct,int lev,int dim)
 {
 int i;
 INTEGER64 mask;
@@ -710,9 +717,11 @@ INTEGER64 mask;
 	if ( rct.br.y >= m->pixel_size[1] )
 		rct.br.y = m->pixel_size[1];
 	start[1] = rct.tl.x;
-	start[2] = rct.tl.y;
+	if ( dim == 2 )
+		start[2] = rct.tl.y;
 	end[1] = ceil(rct.br.x);
-	end[2] = ceil(rct.br.y);
+	if ( dim == 2 )
+		end[2] = ceil(rct.br.y);
 	start[0] = end[0] = inc[0] = lev;
 	for ( i = 3 ; i <= m->p.dim ; i ++ ) {
 		start[i] = 0;
@@ -1120,7 +1129,7 @@ int er_code;
 		rct.tl.y *= r->pr64.dpm;
 		rct.br.x *= r->pr64.dpm;
 		rct.br.y *= r->pr64.dpm;
-		set_search_parameter(r->h.mtx,start,end,inc,rct,lev);
+		set_search_parameter(r->h.mtx,start,end,inc,rct,lev,r->h.mtx->p.dim);
 		
 		for ( i = 0 ; i <= r->h.mtx->p.dim ; i ++ )
 			ix[i] = start[i];
@@ -1272,7 +1281,7 @@ int er_code;
 					continue;
 }
 				if ( (*ip_p)->onmap == 0 ) {
-//ss_printf("PG PLOT ONMAP-1\n");
+ss_printf("PG PLOT ONMAP-1\n");
 
 					ac = get_arg_cache(vmp,*ip_p);
 					if ( ac->onmap == 0  ) {
@@ -1281,18 +1290,25 @@ int er_code;
 						XL_SEXP * data;
 						XL_SEXP * sym;
 						int list_f;
-//ss_printf("PG PLOT ONMAP-2 %i\n",vmp->direct_onmap_field);
+/*
+ss_printf("PG PLOT ONMAP-2 %i\n",vmp->direct_onmap_field);
+*/
 							list_f = 0;
 							gc_push(0,0,"onmap");
 							if ( vmp->direct_onmap_field >= 
 									(*ip_p)->fields[0].len )
 								goto ac_error;
 							fd = &(*ip_p)->fields[vmp->direct_onmap_field];
-//ss_printf("PG PLOT ONMAP-3 %x\n",fd->type);
+/*
+ss_printf("PG PLOT ONMAP-3 %x %x\n",fd->type,CH_STRING);
+*/
 							switch ( fd->type ) {
 							case CH_STRING:
 								data = get_string(
 									l_string(&utf8_cm,fd->d.str));
+/*
+ss_printf("DATA %x %x :: %x\n",fd->d.str[0],fd->d.str[1],data->string.data[0]);
+*/
 								break;
 							case CH_INT_ADD:
 							case CH_INT_AVG:
@@ -1351,7 +1367,9 @@ int er_code;
 							s = eval(env,(XL_SEXP*)vmp->ind_convert->data);
 							er_code = 1;
 							if ( get_type(s) != XLT_ERROR ) {
-//ss_printf("PG PLOT ONMAP-2-1\n");
+/*
+ss_printf("PG PLOT ONMAP-2-1\n");
+*/
 								er_code = 2;
 								s = get_onmap_info(r,vmp->ischeme,s,&style_reso);
 								if ( get_type(s) != XLT_ERROR ) {
@@ -1411,7 +1429,11 @@ int er_code;
 //ss_printf("PG PLOT ONMAP-5-1\n");
 				if ( (*ip_p)->onmap->data == 0 )
 					continue;
-//ss_printf("PG PLOT ONMAP-6\n");
+/*
+ss_printf("PG PLOT ONMAP-6\n");
+print_sexp(s_stdout,(*ip_p)->onmap->data,0);
+ss_printf("\n");
+*/
 				pic = get_onmap_string_pic(gf,(*ip_p)->onmap->data);
 				if ( pic.list == 0 ){
 					free_pic(pic);
@@ -1526,6 +1548,7 @@ int div;
 int i;
 INTEGER64 * start,*end,*inc,*ix;
 int err;
+int err_flag;
 
 	if ( dw->method == 0 )
 		return; 
@@ -1596,11 +1619,13 @@ ss_printf("DUMMY MATRIX OK\n");
 		rct.tl.y *= r->pr64.dpm;
 		rct.br.x *= r->pr64.dpm;
 		rct.br.y *= r->pr64.dpm;
-		set_search_parameter(r->h.mtx,start,end,inc,rct,lev);
+		set_search_parameter(r->h.mtx,start,end,inc,rct,lev,r->h.mtx->p.dim);
 		
 		for ( i = 0 ; i <= r->h.mtx->p.dim ; i ++ )
 			ix[i] = start[i];
+		err_flag = 0;
 		for ( ; ; ) {
+			err = 0;
 			if ( r->h.mtx->p.flags & MPF_NODE_DIPENDENT ) {
 				n = get_matrix_tree(&err,r->h.mtx,ix,GN_NODE_CREATE,r->h.loop_no);
 			}
@@ -1609,9 +1634,16 @@ ss_printf("DUMMY MATRIX OK\n");
 			}
 			if ( n )
 				unlock_node(n,0);
+			if ( err )
+				err_flag = 1;
 			if ( inc_dim_code_ix(ix,start,inc,end,r->h.mtx->p.dim) )
 				break;
 		}
+		if ( err_flag == 0 ) {
+			lock_task(res_lock);
+			r->h.non_setup_vm = setup_view_methods(r,0,vm_tbl[r->h.type],&r->h.vm);
+			unlock_task(res_lock,"insert_resource_matrix");
+		}
 		
 	end:
 		;
