@@ -263,7 +263,7 @@ TREE_CACHE_T * n;
 	n->tn = tn;
 	n->data = 0;
 	n->tmp = 0;
-	n->loop_no = tc->r->pr64.loop_no;
+	n->loop_no = tc->r->h.loop_no;
 	n->req_level = req_level;
 	tn->flags |= TNF_REQUEST;
 	tn->lock ++;
@@ -826,7 +826,7 @@ WFID_INCLUDE_RESOURCE * wir;
 				break;
 			}
 			unlock_task(tc_lock,"tc_task");
-			if ( n1->tc->r->pr64.loop_no - n1->loop_no
+			if ( n1->tc->r->h.loop_no - n1->loop_no
 					> spiral_count + 2 ||
 				(wir = wf_search_wfid_include_resource(n1->tc->r))
 					== 0 ) {
