@@ -24,6 +24,8 @@
 #define PRI_OFFSET_RATE		20
 
 void ov_default();
+void _wakeup_win_manage(void *);
+void wakeup_win_manage(void *);
 
 
 int
@@ -71,6 +73,7 @@ int ret;
 		goto end;
 	}
 	wf = d_alloc(sizeof(*wf));
+	memset(wf,0,sizeof(*wf));
 	wf->pri_adj = 0;
 	wf->id = _get_new_wfid(gf);
 	wf->tbl = tbl;
@@ -115,9 +118,11 @@ int ret;
 	wf->aboat_count = 0;
 	wf->in_base_time = get_xltime();
 	wf->out_base_time = 0;
+	wf->wa_set = wf_new_work_area_set();
 
 	wf->insert_time = get_xltime();
 	
+	wf_insert_action(gf,wf,wf->flags);
 
 	_wakeup_wf(gf,wf);
 end:
@@ -154,6 +159,7 @@ WIN_FLAME ** wfp;
 	free_mh(wf->mh);
 	d_f_ree(wf->pixels);
 	wf_free_si(wf);
+	wf_close_work_area_set(wf->wa_set);
 	for ( wfp = &gf->flame ; *wfp && *wfp != wf ; wfp = &(*wfp)->next );
 	if ( *wfp )
 		*wfp = wf->next;
@@ -212,10 +218,21 @@ wf_move_y(GBVIEW_FLAME * gf,WIN_FLAME * wf,int dy,GB_RECT * r)
 {
 int x,y;
 unsigned long * dest, * src;
-	
+int cnt;
 	if ( dy == 0 )
 		return;
-	if ( dy > 0 ) {
+	if ( dy >= gf->win_height || dy <= -gf->win_height ) {
+		dest = wf->pixels;
+		cnt = gf->win_width*gf->win_height;
+		for ( ; cnt ; cnt -- ,dest ++ )
+			*dest = C_TRANSPARENT|C_DIRTY;
+		if( r ) {
+			r->tl.x = r->tl.y = 0;
+			r->br.x = gf->win_width;
+			r->br.y = gf->win_height;
+		}
+	}
+	else if ( dy > 0 ) {
 		for ( y = gf->win_height-1 ; y-dy >= 0 ; y -- ) {
 			dest = &wf->pixels[y*gf->win_width];
 			src = &wf->pixels[(y-dy)*gf->win_width];
@@ -226,10 +243,12 @@ unsigned long * dest, * src;
 		for ( y = 0 ; y < dy ; y ++ )
 			for ( x = 0 ; x < gf->win_width ; x ++ )
 				*dest++ = C_TRANSPARENT|C_DIRTY;
-		r->tl.x = 0;
-		r->tl.y = 0;
-		r->br.x = gf->win_width;
-		r->br.y = dy;
+		if ( r ) {
+			r->tl.x = 0;
+			r->tl.y = 0;
+			r->br.x = gf->win_width;
+			r->br.y = dy;
+		}
 	}
 	else {
 		for ( y = 0 ; y < gf->win_height + dy ; y ++ ) {
@@ -242,10 +261,12 @@ unsigned long * dest, * src;
 		for ( y = 0 ; y < - dy ; y ++ )
 			for ( x = 0 ; x < gf->win_width ; x ++ )
 				*dest ++ = C_TRANSPARENT|C_DIRTY;
-		r->tl.x = 0;
-		r->tl.y = gf->win_height+dy;
-		r->br.x = gf->win_width;
-		r->br.y = gf->win_height;
+		if ( r ) {
+			r->tl.x = 0;
+			r->tl.y = gf->win_height+dy;
+			r->br.x = gf->win_width;
+			r->br.y = gf->win_height;
+		}
 	}
 	wf->mov_y += dy;
 }
@@ -309,7 +330,7 @@ int id;
 	cache_image(
 		gf,
 		wf->id,wf->draw,pt_list,pt_reso,buf,length,r,mh,&surp,0,
-		WFF_LUSTER_DIRTY);
+		WFF_LUSTER_DIRTY,0);
 	wf_lock(gf);
 
 	_ex_unlock(gf);
@@ -379,6 +400,31 @@ SYMBOL_INDICATE ** sip, * si1;
 	}
 }
 
+typedef struct e2d_move_wa_t {
+	int		dx,dy;
+} E2D_MOVE_WA_T;
+
+void
+e2d_move_wa_f(I_POINT * ptr,int len,void * w)
+{
+E2D_MOVE_WA_T * t;
+	 t = w;
+	 for ( ; len > 0 ; len -- , ptr ++) {
+		if ( ptr->x == 0x80000000 || ptr->y == 0x80000000 )
+			continue;
+		ptr->x += t->dx;
+		ptr->y += t->dy;
+	 }
+}
+
+void
+e2d_move_wa(WF_WORK_AREA_SET * aset,int dx,int dy)
+{
+E2D_MOVE_WA_T t;
+	t.dx = dx;
+	t.dy = dy;
+	wf_work_area_move(aset,e2d_move_wa_f,&t);
+}
 
 int
 e2d_move(GBVIEW_FLAME * gf,WIN_FLAME * wf,VPOINT from,VPOINT to,
@@ -403,6 +449,8 @@ move must be done in the wf_lock. move_redraw_rect unlock it
 			move_redraw_rect(gf,wf,&r2);
 	}
 */
+	e2d_move_wa(wf->wa_set,dx,dy);
+
 	if ( wf->flags & WFF_LUSTER )
 		wf->flags |= WFF_LUSTER_DIRTY;
 	if ( wf->flags & WFF_POLY )
@@ -549,6 +597,7 @@ SURP_SET surp;
 int id;
 int ci_ret;
 
+	ci_ret = 0;
 	if ( r->tl.x < 0 ) {
 		if ( r->br.x <= 0 )
 			return -1;
@@ -685,7 +734,7 @@ map_test_trace(mh);
 		gf,
 		wf->id,wf->draw,pt_list,pt_reso,buf,
 		w*h,r,mh,&surp,1,
-		WFF_PLOT_DIRTY|WFF_LUSTER_DIRTY);
+		WFF_PLOT_DIRTY|WFF_LUSTER_DIRTY,0);
 
 	wf_lock(gf);
 	_wf = _get_wf_ptr(gf,id);
@@ -718,6 +767,8 @@ end:
 	d_f_ree(pt_list);
 	d_f_ree(pt_reso);
 	free_mh(mh);
+	if ( ci_ret & WFF_FLUSH )
+		return -4;
 	return 0;
 }
 
@@ -787,9 +838,10 @@ int sc;
 int pri_cnt;
 REDRAW_PIXEL rp;
 
-
+int flush_flag = 0;
 
 restart:
+	flush_flag = 0;
 	wf_lock(gf);
 	sc = 0;
 	wf->flags &= ~WFF_RESIZE;
@@ -827,6 +879,9 @@ xx,yy,t,b,l,r);
 		case -3:
 			ret = 2;
 			goto end;
+		case -4:
+			flush_flag = 1;
+			break;
 		default:
 			er_panic("aaa");
 		}
@@ -846,6 +901,17 @@ end:
 	if ( spiral_count )
 		_set_pri_adj(gf,wf,pri_cnt*PRI_OFFSET_RATE/spiral_count);
 	else	_set_pri_adj(gf,wf,pri_cnt);
+	if ( flush_flag ) {
+	GB_RECT rct;
+		wf_work_area_flush(wf->wa_set);
+		rct.tl.x = 0;
+		rct.br.x = gf->win_width;
+		rct.tl.y = 0;
+		rct.br.y = gf->win_height;
+		win_flame_dirty(gf,wf->id,&rct,WFF_LUSTER_DIRTY,0);
+
+		goto restart;
+	}
 
 	return ret;
 }
@@ -955,6 +1021,25 @@ e2d_overlay(GBVIEW_FLAME * gf,WIN_FLAME * wf,OV_ARG * a)
 	return 0;
 }
 
+
+void
+e2d_zoom_wa_f(I_POINT * ptr,int len,void *w)
+{
+	ptr->x = ptr->y = 0x80000000;
+}
+
+void
+e2d_zoom_wa(WF_WORK_AREA_SET * aset)
+{
+	wf_work_area_move(aset,e2d_zoom_wa_f,0);
+}
+
+void
+e2d_rotate_wa(WF_WORK_AREA_SET * aset)
+{
+	wf_work_area_move(aset,e2d_zoom_wa_f,0);
+}
+
 int
 e2d_zoom(GBVIEW_FLAME * gf,WIN_FLAME * wf,int w,int h,int * ix_x,int * ix_y)
 {
@@ -965,9 +1050,18 @@ int i;
 	for ( i = 0 ; i < gf->win_height*gf->win_width ; i ++ )
 		wf->pixels[i] |= C_DIRTY;
 	wf->flags |= WFF_DIRTY;
+	e2d_zoom_wa(wf->wa_set);
 	return 0;
 }
 
+void
+e2d_resize_wa(WF_WORK_AREA_SET * aset,int old_w,int old_h,int new_w,int new_h)
+{
+E2D_MOVE_WA_T t;
+	t.dx = (new_w - old_w)/2;
+	t.dy = (new_h - old_h)/2;
+	wf_work_area_move(aset,e2d_move_wa_f,&t);
+}
 
 
 int
@@ -975,7 +1069,7 @@ e2d_resize(GBVIEW_FLAME * gf,WIN_FLAME * wf,int old_w,int old_h)
 {
 unsigned long * pixels;
 	pixels = wf_get_resize_data(wf->pixels,old_w,old_h,gf->win_width,gf->win_height,C_DIRTY);
-
+	e2d_resize_wa(wf->wa_set,old_w,old_h,gf->win_width,gf->win_height);
 	d_f_ree(wf->pixels);
 	wf->pixels = pixels;;
 	if ( wf->flags & WFF_LUSTER )
@@ -1001,6 +1095,7 @@ int i;
 	d_f_ree(wf->pixels);
 	wf->pixels = plane;
 	wf_free_si(wf);
+	e2d_rotate_wa(wf->wa_set);
 	if ( wf->flags & WFF_LUSTER )
 		wf->flags |= WFF_LUSTER_DIRTY;
 	if ( wf->flags & WFF_POLY )
@@ -1029,3 +1124,313 @@ I_RECT rct;
 
 
 
+void
+e2d_calc_pitch(GBVIEW_FLAME * gf,int flag)
+{
+GB_POINT pp;
+REAL1 reso;
+REAL1 x_sign,y_sign;
+
+	if ( gf->flame_base->draw->c.geometory_type & GT_A_X_REV ) 
+		x_sign = -1;
+	else	x_sign = 1;
+	if ( gf->flame_base->draw->c.geometory_type & GT_A_Y_REV )
+		y_sign = 1;
+	else	y_sign = -1;
+
+	pp.x = ((REAL1)gf->win_width)/2;
+	pp.y = ((REAL1)gf->win_height)/2;
+	reso = 1;
+	if ( flag == 0 ) {
+		map_from_flame(
+			&gf->flame_base_display_map,
+			&pp,
+			&reso,
+			1);
+		gf->flame_base_center = pp;
+	}
+       	gf->flame_base_display_map.d.ln.reverse.org.x =
+		(-(cos(gf->flame_base_rotate)*gf->win_width
+				+
+		  sin(gf->flame_base_rotate)*gf->win_height)
+			/(2*gf->flame_base_resolution)
+		+ x_sign*gf->flame_base_center.x) * x_sign;
+	gf->flame_base_display_map.d.ln.reverse.org.y =
+		(-(-sin(gf->flame_base_rotate)*gf->win_width
+				+
+		  cos(gf->flame_base_rotate)*gf->win_height)
+			/(2*gf->flame_base_resolution)
+		+ y_sign*gf->flame_base_center.y) * y_sign;
+	gf->flame_base_display_map.d.ln.reverse.matrix[0][0] =
+		cos(gf->flame_base_rotate)/gf->flame_base_resolution*x_sign;
+	gf->flame_base_display_map.d.ln.reverse.matrix[0][1] =
+		sin(gf->flame_base_rotate)/gf->flame_base_resolution*x_sign;
+	gf->flame_base_display_map.d.ln.reverse.matrix[1][0] =
+		-sin(gf->flame_base_rotate)/gf->flame_base_resolution*y_sign;
+	gf->flame_base_display_map.d.ln.reverse.matrix[1][1] =
+		cos(gf->flame_base_rotate)/gf->flame_base_resolution*y_sign;
+
+	gf->flame_base_display_map.d.ln.forward.org.x =
+		((REAL1)gf->win_width)/2 -
+		(cos(gf->flame_base_rotate)*gf->flame_base_center.x*x_sign
+		- sin(gf->flame_base_rotate)*gf->flame_base_center.y*y_sign)*
+			gf->flame_base_resolution;
+	gf->flame_base_display_map.d.ln.forward.org.y =
+		((REAL1)gf->win_height)/2 -
+		(sin(gf->flame_base_rotate)*gf->flame_base_center.x*x_sign
+		+ cos(gf->flame_base_rotate)*gf->flame_base_center.y*y_sign)*
+			gf->flame_base_resolution;
+	gf->flame_base_display_map.d.ln.forward.matrix[0][0] =
+		cos(gf->flame_base_rotate)*gf->flame_base_resolution*x_sign;
+	gf->flame_base_display_map.d.ln.forward.matrix[0][1] =
+		-sin(gf->flame_base_rotate)*gf->flame_base_resolution*y_sign;
+	gf->flame_base_display_map.d.ln.forward.matrix[1][0] =
+		sin(gf->flame_base_rotate)*gf->flame_base_resolution*x_sign;
+	gf->flame_base_display_map.d.ln.forward.matrix[1][1] =
+		cos(gf->flame_base_rotate)*gf->flame_base_resolution*y_sign;
+
+	gf->flame_base_display_map.d.ln.forward_reso_rate = 1;
+	gf->flame_base_display_map.d.ln.reverse_reso_rate = 1;
+
+	gf->flame_base_display_map.type = MHT_LINEAR;
+	gf->flame_base_display_map.dir = MHD_REVERSE;
+}
+
+
+void
+wf_move_redraw_x(GBVIEW_FLAME * gf,int dx)
+{
+int x,y;
+char * dest, * src;
+unsigned long * rd, * rs;
+I_RECT rr;
+	if ( dx == 0 )
+		return;
+	gf->redraw_r.tl.x += dx;
+	if ( gf->redraw_r.tl.x < 0 )
+		gf->redraw_r.tl.x = 0;
+	if ( gf->redraw_r.tl.x >= gf->win_width )
+		gf->redraw_r.tl.x = gf->win_width;
+	gf->redraw_r.br.x += dx;
+	if ( gf->redraw_r.br.x < 0 )
+		gf->redraw_r.br.x = 0;
+	if ( gf->redraw_r.br.x >= gf->win_width )
+		gf->redraw_r.br.x = gf->win_width;
+
+	if ( dx > 0 ) {
+		rr.tl.x = rr.tl.y = 0;
+		rr.br.x = dx;
+		rr.br.y = gf->win_height;
+		insert_redraw_r(gf,&rr);
+
+		for ( y = 0 ; y < gf->win_height ; y ++ ) {
+			dest = &gf->redraw[(y+1)*gf->win_width];
+			src = &gf->redraw[(y+1)*gf->win_width - dx];
+			for ( x = gf->win_width-dx ; x > 0 ; x -- ) {
+				dest --;
+				src --;
+				*dest = *src;
+			}
+			dest = &gf->redraw[y*gf->win_width];
+			for ( x = dx ; x > 0 ; x -- )
+				*dest++ = RP_REDRAW;
+
+			rd = &gf->redraw_plane[(y+1)*gf->win_width];
+			rs = &gf->redraw_plane[(y+1)*gf->win_width - dx];
+			for ( x = gf->win_width-dx ; x > 0 ; x -- ) {
+				rs --;
+				rd --;
+				*rd = *rs;
+			}
+			rd = &gf->redraw_plane[y*gf->win_width];
+			for ( x = dx ; x > 0 ; x -- )
+				*rd ++ = BACKGROUND_COLOR;
+		}
+
+	}
+	else {
+		rr.tl.x = gf->win_width + dx;
+		rr.tl.y = 0;
+		rr.br.x = gf->win_width;
+		rr.br.y = gf->win_height;
+		insert_redraw_r(gf,&rr);
+		for ( y = 0 ; y < gf->win_height ; y ++ ) {
+			dest = &gf->redraw[y*gf->win_width];
+			src = &gf->redraw[y*gf->win_width - dx];
+			for ( x = gf->win_width+dx ; x > 0 ; x -- )
+				*dest ++ = *src ++;
+			dest = &gf->redraw[(y+1)*gf->win_width + dx];
+			for ( x = - dx ; x > 0 ; x -- )
+				*dest++ = RP_REDRAW;
+
+			rd = &gf->redraw_plane[y*gf->win_width];
+			rs = &gf->redraw_plane[y*gf->win_width - dx];
+			for ( x = gf->win_width+dx ; x > 0 ; x -- )
+				*rd ++ = *rs ++;
+			rd = &gf->redraw_plane[(y+1)*gf->win_width + dx];
+			for ( x = - dx ; x > 0 ; x -- )
+				*rd++ = BACKGROUND_COLOR;
+		}
+	}
+}
+
+void
+wf_move_redraw_y(GBVIEW_FLAME * gf,int dy)
+{
+int x,y;
+char * dest, * src;
+unsigned long * rd, * rs;
+I_RECT rr;
+	if ( dy == 0 )
+		return;
+	gf->redraw_r.tl.y += dy;
+	gf->redraw_r.br.y += dy;
+	if ( gf->redraw_r.tl.y < 0 )
+		gf->redraw_r.tl.y = 0;
+	if ( gf->redraw_r.br.y < 0 )
+		gf->redraw_r.br.y = 0;
+	if ( gf->redraw_r.br.y >= gf->win_height )
+		gf->redraw_r.br.y = gf->win_height;
+	if ( gf->redraw_r.tl.y >= gf->win_height )
+		gf->redraw_r.tl.y = gf->win_height;
+	if ( dy > 0 ) {
+		rr.tl.x = rr.tl.y = 0;
+		rr.br.x = gf->win_width;
+		rr.br.y = dy;
+		insert_redraw_r(gf,&rr);
+
+		for ( y = gf->win_height-1 ; y-dy >= 0 ; y -- ) {
+			src = &gf->redraw[(y-dy)*gf->win_width];
+			dest = &gf->redraw[y*gf->win_width];
+			for ( x = 0 ; x < gf->win_width ; x ++ )
+				*dest++ = *src++;
+		}
+		dest = gf->redraw;
+		for ( y = 0 ; y < dy ; y ++ )
+			for ( x = 0 ; x < gf->win_width ; x ++ )
+				*dest++ = RP_REDRAW;
+
+		for ( y = gf->win_height-1 ; y-dy >= 0 ; y -- ) {
+			rs = &gf->redraw_plane[(y-dy)*gf->win_width];
+			rd = &gf->redraw_plane[y*gf->win_width];
+			for ( x = 0 ; x < gf->win_width ; x ++ )
+				*rd++ = *rs++;
+		}
+		rd = gf->redraw_plane;
+		for ( y = 0 ; y < dy ; y ++ )
+			for ( x = 0 ; x < gf->win_width ; x ++ )
+				*rd++ = BACKGROUND_COLOR;
+	}
+	else {
+		rr.tl.x = 0;
+		rr.tl.y = gf->win_height + dy;
+		rr.br.x = gf->win_width;
+		rr.br.y = gf->win_height;
+		insert_redraw_r(gf,&rr);
+
+		for ( y = 0 ; y < gf->win_height + dy ; y ++ ) {
+			src = &gf->redraw[(y-dy)*gf->win_width];
+			dest = &gf->redraw[y*gf->win_width];
+			for ( x = 0 ; x < gf->win_width ; x ++ )
+				*dest++ = *src++;
+		}
+		dest = &gf->redraw[(gf->win_height+dy)*gf->win_width];
+		for ( y = 0 ; y < - dy ; y ++ )
+			for ( x = 0 ; x < gf->win_width ; x ++ )
+				*dest ++ = RP_REDRAW;
+
+		for ( y = 0 ; y < gf->win_height + dy ; y ++ ) {
+			rs = &gf->redraw_plane[(y-dy)*gf->win_width];
+			rd = &gf->redraw_plane[y*gf->win_width];
+			for ( x = 0 ; x < gf->win_width ; x ++ )
+				*rd++ = *rs++;
+		}
+		rd = &gf->redraw_plane[(gf->win_height+dy)*gf->win_width];
+		for ( y = 0 ; y < - dy ; y ++ )
+			for ( x = 0 ; x < gf->win_width ; x ++ )
+				*rd ++ = BACKGROUND_COLOR;
+	}
+}
+
+
+
+void
+set_map_xy(GBVIEW_FLAME * gf,int dx,int dy)
+{
+MAP_HISTORY * mh;
+GB_POINT ptr;
+REAL1 reso;
+	mh = &gf->flame_base_display_map;
+	mh->d.ln.forward.org.x += dx;
+	mh->d.ln.forward.org.y += dy;
+
+	ptr.x = -dx;
+	ptr.y = -dy;
+	mh->d.ln.reverse.org
+		= p_add(mh->d.ln.reverse.org,
+			mp_mul(mh->d.ln.reverse.matrix,ptr));
+
+	ptr.x = gf->win_width/2;
+	ptr.y = gf->win_height/2;
+	reso = 1;
+
+	map_from_flame(&gf->flame_base_display_map,&ptr,&reso,1);
+
+	gf->flame_base_center = ptr;
+}
+
+
+int
+wf_move_xy(GBVIEW_FLAME * gf,VPOINT from,VPOINT to)
+{
+WIN_FLAME * wf;
+SELECT_INDICATE * si;
+int dx,dy;
+
+	dx = to.x - from.x;
+	dy = to.y - from.y;
+
+	set_map_xy(gf,dx,dy);
+
+	for ( wf = gf->flame ; wf ; wf = wf->next ) {
+		if ( wf->flags & (WFF_FREE|WFF_HIDE) )
+			continue;
+		win_flame_move(gf,wf,from,to,0);
+	}
+	for ( si = gf->si ; si ; si = si->next ) {
+		si->x += dx;
+		si->y += dy;
+	}
+	wf_move_redraw_x(gf,dx);
+	wf_move_redraw_y(gf,dy);
+	assert_ls(gf,LSF_MOVE);
+	gf->move_flag = 1;
+	_set_move_timer(gf);
+	_wakeup_win_manage(gf->radar_ptr);
+
+	return _get_env_seq(gf);
+}
+
+
+int
+e2d_move_gen(GBVIEW_FLAME * gf,WIN_FLAME * wf,VPOINT from, VPOINT to,void * ix)
+{
+	return wf_move_xy(gf,from,to);
+}
+
+int 
+e2d_zoom_gen
+	(	GBVIEW_FLAME * gf,
+		struct win_flame * 	wf,
+		int			w,
+		int			h,
+		int *			index_x,
+		int *			index_y)
+{
+	wf_im_zoom_proc(gf->redraw_plane,w,h,index_x,index_y);
+	return 0;
+}
+
+
+
+
