@@ -39,6 +39,7 @@ WIN_FLAME ** wfp;
 	}
 	free_mh(wf->mh);
 	wf_free_si(wf);
+	wf_close_work_area_set(wf->wa_set);
 	for ( wfp = &gf->flame ; *wfp && *wfp != wf ; wfp = &(*wfp)->next );
 	if ( *wfp )
 		*wfp = wf->next;
@@ -58,8 +59,10 @@ e2d_p_move(
 	WIN_FLAME * wf,VPOINT from,VPOINT to,void * _ix)
 {
 VPOINT * ix;
+int dx,dy;
 	ix = _ix;
-	wf_move_si(gf, wf, to.x - from.x, to.y - from.y);
+	wf_move_si(gf, wf, dx = to.x - from.x,dy =  to.y - from.y);
+	e2d_move_wa(wf->wa_set,dx,dy);
 	wf->flags |= WFF_PLOT_DIRTY;
 	return 0;
 }
@@ -103,6 +106,7 @@ WIN_FLAME * _wf;
 SURP_SET surp;
 int id;
 GB_RECT r;
+int ci_ret;
 
 	r.tl.x = r.tl.y = 0;
 	r.br.x = gf->win_width;
@@ -128,9 +132,22 @@ GB_RECT r;
 	id = wf->id;
 	wf_unlock(gf);
 
-	cache_image(gf,wf->id,wf->draw,0,0,0,w*h,&r,mh,&surp,1,
-		WFF_PLOT_DIRTY);
+retry:
+	ci_ret = cache_image(gf,wf->id,wf->draw,0,0,0,w*h,&r,mh,&surp,1,
+		WFF_PLOT_DIRTY,0);
 
+	if ( ci_ret & WFF_FLUSH ) {
+	GB_RECT rct;
+		wf_work_area_flush(wf->wa_set);
+		rct.tl.x = 0;
+		rct.br.x = gf->win_width;
+		rct.tl.y = 0;
+		rct.br.y = gf->win_height;
+		win_flame_dirty(gf,wf->id,&rct,WFF_LUSTER_DIRTY,0);
+
+		goto retry;
+	}
+		
 	wf_lock(gf);
 	_wf = _get_wf_ptr(gf,id);
 	if ( _wf != wf )
@@ -204,7 +221,16 @@ e2d_p_zoom_etc(
 {
 
 	wf_free_si(wf);
+	e2d_zoom_wa(wf->wa_set);
 	wf->flags |= WFF_PLOT_DIRTY;
 	return 0;
 }
 
+int
+e2d_p_resize(GBVIEW_FLAME * gf,WIN_FLAME * wf,int old_w,int old_h)
+{
+	e2d_resize_wa(wf->wa_set,old_w,old_h,gf->win_width,gf->win_height);
+	return 0;
+}
+
+
