@@ -62,6 +62,7 @@ int dx,dy;
 	wf->small_rct.tl.y += dy;
 	wf->small_rct.br.y += dy;
 	wf_move_si(gf,wf,dx,dy);
+	e2d_move_wa(wf->wa_set,dx,dy);
 	return 0;
 }
 
@@ -111,7 +112,7 @@ e2ds_copy_pixels(
 int x,y,i,index;
 unsigned long * dest;
 int f;
-int width;
+int width,r_width;
 int y_index;
 int y_index_gf;
 
@@ -121,13 +122,14 @@ int y_index_gf;
 	r->tl.x += wf->mov_x;
 	r->br.y += wf->mov_y;
 	r->br.x += wf->mov_x;
+	r_width = r->br.x - r->tl.x;
 	i = 0;
 	insert_redraw_gbr(gf,r);
 	f = 0;
 	width = wf->small_rct.br.x - wf->small_rct.tl.x;
 	for ( y = r->tl.y ; y < r->br.y ; y ++ ){
 		if ( y < wf->small_rct.tl.y || y >= wf->small_rct.br.y ) {
-			i ++;
+			i += r_width;
 			continue;
 		}
 		y_index = (y - wf->small_rct.tl.y)*width;
@@ -178,6 +180,7 @@ int width;
 int yy_index;
 unsigned long * target;
 
+	ci_ret = 0;
 	if ( r->tl.x < wf->small_rct.tl.x ) {
 		if ( r->br.x <= wf->small_rct.tl.x )
 			return -1;
@@ -345,7 +348,7 @@ map_test_trace(mh);
 		gf,
 		wf->id,wf->draw,pt_list,pt_reso,buf,
 		w*h,r,mh,&surp,1,
-		WFF_PLOT_DIRTY|WFF_LUSTER_DIRTY);
+		WFF_PLOT_DIRTY|WFF_LUSTER_DIRTY,0);
 
 	wf_lock(gf);
 	_wf = _get_wf_ptr(gf,id);
@@ -380,6 +383,8 @@ end:
 	d_f_ree(pt_reso);
 	free_mh(mh);
 	wf_set_delay_redraw_exec(gf);
+	if ( ci_ret & WFF_FLUSH )
+		return -4;
 	return 0;
 }
 
@@ -491,9 +496,10 @@ int ret;
 int sc;
 int pri_cnt;
 REDRAW_PIXEL rp;
-
+int flush_flag = 0;
 
 restart:
+	flush_flag = 0;
 	wf_lock(gf);
 	sc = 0;
 	wf->flags &= ~WFF_RESIZE;
@@ -532,6 +538,9 @@ xx,yy,t,b,l,r);
 		case -3:
 			ret = 2;
 			goto end;
+		case -4:
+			flush_flag = 1;
+			break;
 		default:
 			er_panic("aaa");
 		}
@@ -550,6 +559,18 @@ end:
 		_set_pri_adj(gf,wf,pri_cnt*PRI_OFFSET_RATE/sc);
 	else	_set_pri_adj(gf,wf,pri_cnt);
 
+	if ( flush_flag ) {
+	GB_RECT rct;
+		wf_work_area_flush(wf->wa_set);
+		rct.tl.x = 0;
+		rct.br.x = gf->win_width;
+		rct.tl.y = 0;
+		rct.br.y = gf->win_height;
+		win_flame_dirty(gf,wf->id,&rct,WFF_LUSTER_DIRTY,0);
+
+		goto restart;
+	}
+
 	return ret;
 }
 
@@ -647,7 +668,7 @@ int width;
 	return 0;
 }
 
-/***/
+
 int
 e2ds_overlay(GBVIEW_FLAME * gf,WIN_FLAME * wf,OV_ARG * a)
 {
@@ -748,6 +769,7 @@ int width,height;
 		}
 	}
 	
+	e2d_zoom_wa(wf->wa_set);
 	d_f_ree(wf->pixels);
 	wf->pixels = target;
 	wf->small_rct = new_rct;
@@ -770,6 +792,7 @@ int w_ofs,h_ofs;
 	wf->small_rct.br.x += w_ofs;
 	wf->small_rct.br.y += h_ofs;
 	wf->small_resize = 1;
+	e2d_resize_wa(wf->wa_set,old_width,old_height,gf->win_width,gf->win_height);
 	wf_check_small(gf,wf);
 	return 0;
 }
@@ -793,6 +816,8 @@ unsigned long * target;
 	wf->small_rct = new_rct;
 	wf->small_resize = 1;
 
+	e2d_rotate_wa(wf->wa_set);
+
 	wf_check_small(gf,wf);
 	wf_free_si(wf);
 	e2ds_get_weight(gf,wf);
@@ -872,9 +897,6 @@ REAL1 rw,rh;
 		ret.br.y = ceil(r.br.y);
 	}
 
-if ( ret.tl.x < -2000000000 )
-ss_printf("STOP\n");
-
 	return ret;
 }
 
