@@ -1676,6 +1676,7 @@ _xx_free_win_flame(GBVIEW_FLAME * gf,WIN_FLAME * wf,char * __file,int __line)
 	_backup_wf_flags(gf,wf);
 ss_printf("FREE %s(%i) %ls\n",__file,__line,get_url_str2(&wf->draw->h.entry));
 	wf->flags |= WFF_FREE;
+	wf_insert_action(gf,wf,WFF_HIDE);
 	log_printf(LOG_MESSAGE,LOG_LAYER_GB,0,
 		"FREE(%s:%i) %ls\n",
 		__file,__line,
@@ -2199,161 +2200,6 @@ WIN_FLAME * wf;
 }
 
 
-void
-wf_move_redraw_x(GBVIEW_FLAME * gf,int dx)
-{
-int x,y;
-char * dest, * src;
-unsigned long * rd, * rs;
-I_RECT rr;
-	if ( dx == 0 )
-		return;
-	gf->redraw_r.tl.x += dx;
-	if ( gf->redraw_r.tl.x < 0 )
-		gf->redraw_r.tl.x = 0;
-	if ( gf->redraw_r.tl.x >= gf->win_width )
-		gf->redraw_r.tl.x = gf->win_width;
-	gf->redraw_r.br.x += dx;
-	if ( gf->redraw_r.br.x < 0 )
-		gf->redraw_r.br.x = 0;
-	if ( gf->redraw_r.br.x >= gf->win_width )
-		gf->redraw_r.br.x = gf->win_width;
-
-	if ( dx > 0 ) {
-		rr.tl.x = rr.tl.y = 0;
-		rr.br.x = dx;
-		rr.br.y = gf->win_height;
-		insert_redraw_r(gf,&rr);
-
-		for ( y = 0 ; y < gf->win_height ; y ++ ) {
-			dest = &gf->redraw[(y+1)*gf->win_width];
-			src = &gf->redraw[(y+1)*gf->win_width - dx];
-			for ( x = gf->win_width-dx ; x > 0 ; x -- ) {
-				dest --;
-				src --;
-				*dest = *src;
-			}
-			dest = &gf->redraw[y*gf->win_width];
-			for ( x = dx ; x > 0 ; x -- )
-				*dest++ = RP_REDRAW;
-
-			rd = &gf->redraw_plane[(y+1)*gf->win_width];
-			rs = &gf->redraw_plane[(y+1)*gf->win_width - dx];
-			for ( x = gf->win_width-dx ; x > 0 ; x -- ) {
-				rs --;
-				rd --;
-				*rd = *rs;
-			}
-			rd = &gf->redraw_plane[y*gf->win_width];
-			for ( x = dx ; x > 0 ; x -- )
-				*rd ++ = BACKGROUND_COLOR;
-		}
-
-	}
-	else {
-		rr.tl.x = gf->win_width + dx;
-		rr.tl.y = 0;
-		rr.br.x = gf->win_width;
-		rr.br.y = gf->win_height;
-		insert_redraw_r(gf,&rr);
-		for ( y = 0 ; y < gf->win_height ; y ++ ) {
-			dest = &gf->redraw[y*gf->win_width];
-			src = &gf->redraw[y*gf->win_width - dx];
-			for ( x = gf->win_width+dx ; x > 0 ; x -- )
-				*dest ++ = *src ++;
-			dest = &gf->redraw[(y+1)*gf->win_width + dx];
-			for ( x = - dx ; x > 0 ; x -- )
-				*dest++ = RP_REDRAW;
-
-			rd = &gf->redraw_plane[y*gf->win_width];
-			rs = &gf->redraw_plane[y*gf->win_width - dx];
-			for ( x = gf->win_width+dx ; x > 0 ; x -- )
-				*rd ++ = *rs ++;
-			rd = &gf->redraw_plane[(y+1)*gf->win_width + dx];
-			for ( x = - dx ; x > 0 ; x -- )
-				*rd++ = BACKGROUND_COLOR;
-		}
-	}
-}
-
-void
-wf_move_redraw_y(GBVIEW_FLAME * gf,int dy)
-{
-int x,y;
-char * dest, * src;
-unsigned long * rd, * rs;
-I_RECT rr;
-	if ( dy == 0 )
-		return;
-	gf->redraw_r.tl.y += dy;
-	gf->redraw_r.br.y += dy;
-	if ( gf->redraw_r.tl.y < 0 )
-		gf->redraw_r.tl.y = 0;
-	if ( gf->redraw_r.br.y < 0 )
-		gf->redraw_r.br.y = 0;
-	if ( gf->redraw_r.br.y >= gf->win_height )
-		gf->redraw_r.br.y = gf->win_height;
-	if ( gf->redraw_r.tl.y >= gf->win_height )
-		gf->redraw_r.tl.y = gf->win_height;
-	if ( dy > 0 ) {
-		rr.tl.x = rr.tl.y = 0;
-		rr.br.x = gf->win_width;
-		rr.br.y = dy;
-		insert_redraw_r(gf,&rr);
-
-		for ( y = gf->win_height-1 ; y-dy >= 0 ; y -- ) {
-			src = &gf->redraw[(y-dy)*gf->win_width];
-			dest = &gf->redraw[y*gf->win_width];
-			for ( x = 0 ; x < gf->win_width ; x ++ )
-				*dest++ = *src++;
-		}
-		dest = gf->redraw;
-		for ( y = 0 ; y < dy ; y ++ )
-			for ( x = 0 ; x < gf->win_width ; x ++ )
-				*dest++ = RP_REDRAW;
-
-		for ( y = gf->win_height-1 ; y-dy >= 0 ; y -- ) {
-			rs = &gf->redraw_plane[(y-dy)*gf->win_width];
-			rd = &gf->redraw_plane[y*gf->win_width];
-			for ( x = 0 ; x < gf->win_width ; x ++ )
-				*rd++ = *rs++;
-		}
-		rd = gf->redraw_plane;
-		for ( y = 0 ; y < dy ; y ++ )
-			for ( x = 0 ; x < gf->win_width ; x ++ )
-				*rd++ = BACKGROUND_COLOR;
-	}
-	else {
-		rr.tl.x = 0;
-		rr.tl.y = gf->win_height + dy;
-		rr.br.x = gf->win_width;
-		rr.br.y = gf->win_height;
-		insert_redraw_r(gf,&rr);
-
-		for ( y = 0 ; y < gf->win_height + dy ; y ++ ) {
-			src = &gf->redraw[(y-dy)*gf->win_width];
-			dest = &gf->redraw[y*gf->win_width];
-			for ( x = 0 ; x < gf->win_width ; x ++ )
-				*dest++ = *src++;
-		}
-		dest = &gf->redraw[(gf->win_height+dy)*gf->win_width];
-		for ( y = 0 ; y < - dy ; y ++ )
-			for ( x = 0 ; x < gf->win_width ; x ++ )
-				*dest ++ = RP_REDRAW;
-
-		for ( y = 0 ; y < gf->win_height + dy ; y ++ ) {
-			rs = &gf->redraw_plane[(y-dy)*gf->win_width];
-			rd = &gf->redraw_plane[y*gf->win_width];
-			for ( x = 0 ; x < gf->win_width ; x ++ )
-				*rd++ = *rs++;
-		}
-		rd = &gf->redraw_plane[(gf->win_height+dy)*gf->win_width];
-		for ( y = 0 ; y < - dy ; y ++ )
-			for ( x = 0 ; x < gf->win_width ; x ++ )
-				*rd ++ = BACKGROUND_COLOR;
-	}
-}
-
 void
 xx_wf_wakeup(GBVIEW_FLAME * gf,char * __f,int __l)
 {
@@ -2366,148 +2212,6 @@ WIN_FLAME * wf;
 	wf_unlock(gf);
 }
 
-void
-set_map_xy(GBVIEW_FLAME * gf,int dx,int dy)
-{
-MAP_HISTORY * mh;
-GB_POINT ptr;
-REAL1 reso;
-	mh = &gf->flame_base_display_map;
-	mh->d.ln.forward.org.x += dx;
-	mh->d.ln.forward.org.y += dy;
-
-	ptr.x = -dx;
-	ptr.y = -dy;
-	mh->d.ln.reverse.org
-		= p_add(mh->d.ln.reverse.org,
-			mp_mul(mh->d.ln.reverse.matrix,ptr));
-
-	ptr.x = gf->win_width/2;
-	ptr.y = gf->win_height/2;
-	reso = 1;
-
-	map_from_flame(&gf->flame_base_display_map,&ptr,&reso,1);
-
-	gf->flame_base_center = ptr;
-}
-
-
-int
-wf_move_xy(GBVIEW_FLAME * gf,VPOINT from,VPOINT to)
-{
-WIN_FLAME * wf;
-SELECT_INDICATE * si;
-int dx,dy;
-
-	dx = to.x - from.x;
-	dy = to.y - from.y;
-
-	set_map_xy(gf,dx,dy);
-
-	for ( wf = gf->flame ; wf ; wf = wf->next ) {
-		if ( wf->flags & (WFF_FREE|WFF_HIDE) )
-			continue;
-		win_flame_move(gf,wf,from,to,0);
-	}
-	for ( si = gf->si ; si ; si = si->next ) {
-		si->x += dx;
-		si->y += dy;
-	}
-	wf_move_redraw_x(gf,dx);
-	wf_move_redraw_y(gf,dy);
-	assert_ls(gf,LSF_MOVE);
-	gf->move_flag = 1;
-	_set_move_timer(gf);
-	_wakeup_win_manage(gf->radar_ptr);
-
-	return _get_env_seq(gf);
-}
-
-
-int
-wf_move_globe(GBVIEW_FLAME * gf,VPOINT from,VPOINT to)
-{
-WIN_FLAME * wf;
-GB_POINT gb_from,gb_to;
-double radius;
-RESOURCE * r;
-int x,y,ix;
-char * rp, * _rp;
-unsigned long * rpp,* _rpp;
-int w,h;
-int er;
-GLOBE_MOVE_T gt;
-I_POINT * ixp;
-I_RECT ir;
-
-	w = gf->win_width;
-	h = gf->win_height;
-
-	new_rotate_and_center(gf,v2gb_point(from),v2gb_point(to));
-
-	r = gf->flame_base->draw;
-	radius = conv_unit(&er,
-			r->h.cu.uenv,
-			gf->flame_base_resolution,
-			reso_c_unit(&r->h.cu),
-			l_string(std_cm,"dot/rad"));
-
-	gt.ix = d_alloc(sizeof(I_POINT)*w*h);
-	gt.radius = radius;
-	if ( wf_make_gmatrix_index(gt.ix,
-			gb_from = v2gb_point(from),
-			gb_to = v2gb_point(to),radius,w,h) < 0 ) {
-		d_f_ree(gt.ix);
-		return 0;
-	}
-	get_gmatrix(gt.rm,gb_from,gb_to,radius);
-	get_inv_gmatrix(gt.rev_rm,gb_from,gb_to,radius);
-
-	for ( wf = gf->flame ; wf ; wf = wf->next ) {
-		if ( wf->flags & (WFF_FREE|WFF_HIDE) )
-			continue;
-		win_flame_move(gf,wf,from,to,&gt);
-	}
-
-	_wf_purge_select(gf);
-
-	_rp = rp = d_alloc(w*h);
-	_rpp = rpp = d_alloc(sizeof(long)*w*h);
-	ixp = gt.ix;
-	ir.tl.x = ir.tl.y = 0;
-	ir.br.x = ir.br.y = -1;
-	for ( y = 0 ; y < h ; y ++ )
-		for ( x = 0 ; x < w ; x ++ , ixp ++ , rp ++ , rpp ++ ) {
-			if ( ixp->x < 0 )
-				goto no_data;
-			ix = ixp->x + ixp->y * w;
-			*rp = gf->redraw[ix];
-			*rpp = gf->redraw_plane[ix];
-			if ( *rp == RP_REDRAW )
-				insert_vrect(&ir,x,y);
-			continue;
-		no_data:
-			*rp = RP_REDRAW;
-			*rpp = BACKGROUND_COLOR;
-			insert_vrect(&ir,x,y);
-		}
-	gf->redraw_r.tl.x = gf->redraw_r.tl.y 
-		= gf->redraw_r.br.x = gf->redraw_r.br.y = 0;
-	insert_redraw_r(gf,&ir);
-	d_f_ree(gt.ix);
-	d_f_ree(gf->redraw);
-	gf->redraw = _rp;
-	d_f_ree(gf->redraw_plane);
-	gf->redraw_plane = _rpp;
-	assert_ls(gf,LSF_MOVE);
-	gf->move_flag = 1;
-	_set_move_timer(gf);
-	_wakeup_win_manage(gf->radar_ptr);
-
-	return _get_env_seq(gf);
-}
-
-
 int
 wf_move(GBVIEW_FLAME * gf,VPOINT from,VPOINT to)
 {
@@ -2515,7 +2219,7 @@ int ret;
 
 	wf_lock(gf);
 	ZONBIE_CHECK(gf,wf_unlock(gf),0)
-
+/*
 	switch ( gf->flame_base_display_map.type ) {
 	case 0:
 		ret = 0;
@@ -2529,6 +2233,9 @@ int ret;
 	default:
 		er_panic("wf_move");
 	}
+*/
+	ret = (*wf_geo_type_list[gf->flame_base_geo_type][WFT_GEN]->f_move)(gf,0,from,to,0);
+
 	if ( gf->history_enable )
 		gf->history_flag = 1;
 //	_wf_set_delay_redraw(gf);
@@ -2627,8 +2334,11 @@ VRECT rr;
 		wf->mov_flag = 1;
 		_wakeup_wf(gf,wf);
 	}
-
+/*
 	wf_im_zoom_proc(gf->redraw_plane,ow,oh,index_x,index_y);
+*/
+	(*wf_geo_type_list[gf->flame_base_geo_type][WFT_GEN]->f_zoom)(gf,0,ow,oh,index_x,index_y);
+
 	_calc_pitch(gf,0);
 
 	len = gf->win_width*gf->win_height;
@@ -3321,7 +3031,8 @@ wf_goto_point(
 	L_CHAR * url,
 	GB_POINT ptr,
 	REAL1 rotate,
-	REAL1 reso)
+	REAL1 reso,
+	int flags)
 {
 URL u;
 WIN_FLAME * wf;
@@ -3400,9 +3111,12 @@ int ses;
 		return 0;
 	}
 	if ( wf == gf->flame_base ) {
-		gf->flame_base_resolution = reso;
-		gf->flame_base_rotate = rotate;
-		gf->flame_base_center = ptr;
+		if ( (flags & GP_IGN_RESO) == 0 )
+			gf->flame_base_resolution = reso;
+		if ( (flags & GP_IGN_ROTATE) == 0 )
+			gf->flame_base_rotate = rotate;
+		if ( (flags & GP_IGN_PTR) == 0 )
+			gf->flame_base_center = ptr;
 	}
 	else {
 	GB_POINT ptr_list[2];
@@ -3429,19 +3143,21 @@ int ses;
 		if ( reso_list[0] <= 0 )
 			goto wf_0;
 		if ( reso_list[1] <= 0 ) {
-			gf->flame_base_resolution = reso_list[0];
-			gf->flame_base_center = ptr_list[0];
-			gf->flame_base_rotate = rotate;
+			if ( (flags & GP_IGN_RESO) == 0 )
+				gf->flame_base_resolution = reso_list[0];
+			if ( (flags & GP_IGN_PTR) == 0 )
+				gf->flame_base_center = ptr_list[0];
+			if ( (flags & GP_IGN_ROTATE) == 0 )
+				gf->flame_base_rotate = rotate;
 		}
 		else {
-			gf->flame_base_resolution = reso_list[0];
-			gf->flame_base_center = ptr_list[0];
-/* mori
-			gf->flame_base_rotate = get_rad(
-				p_sub(ptr_list[1],ptr_list[0]));
-*/
-			gf->flame_base_rotate = rotate - get_rad(
-				p_sub(ptr_list[1],ptr_list[0]));
+			if ( (flags & GP_IGN_RESO) == 0 )
+				gf->flame_base_resolution = reso_list[0];
+			if ( (flags & GP_IGN_PTR) == 0 )
+				gf->flame_base_center = ptr_list[0];
+			if ( (flags & GP_IGN_ROTATE) == 0 )
+				gf->flame_base_rotate = rotate - get_rad(
+					p_sub(ptr_list[1],ptr_list[0]));
 		}
 	}
 	_calc_pitch(gf,1);
@@ -4150,6 +3866,80 @@ int i;
 }
 
 
+void
+wf_insert_dirty_rect_1d(RESOURCE * r,GB_RECT * d_rect,
+	int flags,
+	int ofs_w,int ofs_h)
+{
+SURP_SET ss;
+MAP_HISTORY * mh;
+RESOURCE * draw;
+GB_RECT rct,* _rct;
+int nos;
+RESOURCE * map;
+WFID_INCLUDE_RESOURCE * wir,* p;
+WIN_FLAME * wf;
+int mask;
+int i;
+int y_top,y_bottom;
+	mask = 0;
+	wir = wf_search_wfid_include_resource(r);
+	for ( p = wir ; p ; p = p->next ) {
+		if ( p->id == 0 )
+			continue;
+		wf_lock(p->gf);
+		wf = _get_wf_ptr(p->gf,p->id);
+		if ( wf ) {
+			mask = wf_get_dirty_mask(wf->flags);
+		}
+		y_top = p->gf->flame_base_y_offset + wf->e1d_y_top + wf->e1d_top_mergin;
+		y_bottom = p->gf->flame_base_y_offset + wf->e1d_y_bottom + wf->e1d_bottom_mergin;
+		wf_unlock(p->gf);
+		if ( (flags & mask) == 0 )
+			continue;
+
+		set_surp(&ss,d_rect,1);
+		draw = wf_get_mh(p->gf,p->id,&mh);
+		if ( draw == 0 )
+			goto next3;
+		if ( draw == r )
+			goto draw_point;
+		map = get_map_between2(r,draw);
+		if ( map == 0 )
+			goto next2;
+		map_conv_forward(map,ss.ptr,ss.reso,SURP_NOS);
+		for ( i = 0 ; i < SURP_NOS ; i ++ )
+			if ( ss.reso[i] < 0 ) {
+				set_surp(&ss,&map->h.minrect,1);
+				break;
+			}
+	draw_point:
+		map_from_resource(mh,ss.ptr,ss.reso,SURP_NOS);
+		memset(ss.group,0,sizeof(ss.group));
+		_rct = get_surp_rect(&nos,&ss,0);
+		if ( nos > 1 )
+			er_panic("wf_insert_dirty_rect");
+		if ( nos == 0 )
+			goto next2;
+		rct = *_rct;
+
+		rct.tl.x -= ofs_w;
+		rct.tl.y = y_top - ofs_h;
+		rct.br.x += ofs_w;
+		rct.br.y = y_bottom + ofs_h;
+
+		win_flame_dirty(p->gf,p->id,&rct,flags & mask,0);
+//	next1:
+		d_f_ree(_rct);
+	next2:
+		free_mh(mh);
+	next3:
+		;
+	}
+	free_wfid_include_resource(wir);
+}
+
+
 int
 _get_wf_pri(GBVIEW_FLAME * gf,WIN_FLAME * wf)
 {
@@ -4332,6 +4122,7 @@ int pri;
 		e->flame_base_unit = ll_copy_str(r->h.cu.unit);
 		e->flame_base_center = gf->flame_base_center;
 		e->flame_base_rotate = gf->flame_base_rotate;
+		e->flame_base_geo_type = gf->flame_base_geo_type;
 
 		e->flags |= SF_RESOLUTION|SF_MAP_TYPE|SF_UNIT|SF_CENTER|SF_ROTATE;
 
@@ -4736,6 +4527,14 @@ WIN_FLAME * wf;
 	wf_unlock(gf);
 }
 
+void
+wf_insert_action(GBVIEW_FLAME * gf,WIN_FLAME * wf,int flags)
+{
+	if ( wf_geo_type_list[gf->flame_base_geo_type][WFT_GEN]->f_wf_insert_action == 0 )
+		return;
+	(*wf_geo_type_list[gf->flame_base_geo_type][WFT_GEN]->f_wf_insert_action)
+			(gf,wf,flags,0,0);
+}
 
 
 int
@@ -4791,7 +4590,7 @@ int hwf_active = 0;
 		goto end;
 	ri->flags &= ~(WFF_COPY_FLAGS&mask);
 	ri->flags |= flags & WFF_COPY_FLAGS;
-ss_printf("RI COPY FLAGS %ls %x %x - %x\n",url,ri->flags,flags,mask);
+//ss_printf("RI COPY FLAGS %ls %x %x - %x\n",url,ri->flags,flags,mask);
 	goto end;
 ok:
 //	flags &= mask;
@@ -4812,9 +4611,11 @@ ss_printf("REAL COPY FLAGS %ls %x -> %x %x - %x\n",url,f,wf->flags,flags,mask);
 			wf->hide_time = get_xltime();
 		if ( flags & WFF_HIDE ) {
 			wf->flags |= WFF_HIDE;
+			wf_insert_action(gf,wf,WFF_HIDE);
 			set_redraw_rect(gf,&rr);
 		}
 		else {
+			wf_insert_action(gf,wf,WFF_HIDE);
 			wf_free_si(wf);
 			_wf_check_resource_wf(gf,wf);
 			_win_flame_dirty(gf,wf,&rr,WFF_DIRTY,0);
@@ -4873,4 +4674,170 @@ int i;
 	d_f_ree(lst);
 }
 
+WF_WORK_AREA *
+wf_new_work_area(WF_WORK_AREA_SET * aset,WF_WORK_AREA_TBL * tbl,RESOURCE * r,int size)
+{
+WF_WORK_AREA * a;
+	lock_task(gbview_flame_lock);
+	for ( a = aset->wa_list ; a ; a = a->next )
+		if ( a->r == r ) {
+			a = 0;
+			goto err;
+		}
+	a = d_alloc(size);
+	a->tbl = tbl;
+	a->r = r;
+	a->checkout = 1;
+	a->freeflag = 0;
+	a->next = aset->wa_list;
+	aset->wa_list = a;
+err:
+	unlock_task(gbview_flame_lock,"");
+	return a;
+}
+
+WF_WORK_AREA *
+wf_checkout_work_area(WF_WORK_AREA_SET * aset,RESOURCE * r)
+{
+WF_WORK_AREA * a;
+	lock_task(gbview_flame_lock);
+	for ( a = aset->wa_list ;a ;a = a->next )
+		if ( a->r == r ) {
+			a->checkout ++;
+			break;
+		}
+	unlock_task(gbview_flame_lock,"");
+	return a;
+}
+
+int
+wf_checkin_work_area(WF_WORK_AREA * a)
+{
+	lock_task(gbview_flame_lock);
+	a->checkout --;
+	if ( a->checkout < 0 )
+		er_panic("wf_checkin_work_area");
+	if ( a == 0 && a->freeflag ) {
+		(*a->tbl->close)(a);
+	}
+	unlock_task(gbview_flame_lock,"");
+	return 0;
+}
+
+
+void
+_wf_close_work_area_set(WF_WORK_AREA_SET * aset)
+{
+WF_WORK_AREA * a, * a2;
+	for ( a = aset->wa_list ; a ; ) {
+		if ( a->checkout ) {
+			a->freeflag = 1;
+			a = a->next;
+		}
+		else {
+			a2 = a->next;
+			(a->tbl->close)(a);
+			a = a2;
+		}
+	}
+	aset->wa_list = 0;
+}
+
+void
+wf_close_work_area_set(WF_WORK_AREA_SET * aset)
+{
+	lock_task(gbview_flame_lock);
+	if ( aset->checkout )
+		aset->freeflag = 1;
+	else	_wf_close_work_area_set(aset);
+	unlock_task(gbview_flame_lock,"");
+}
+
+void
+wf_work_area_move(WF_WORK_AREA_SET * aset,void (*move_func)(I_POINT * ptr,int len,void * work),void * work)
+{
+WF_WORK_AREA * a;
+I_POINT * buffer;
+int buffer_len;
+int p;
+int gsize;
+	lock_task(gbview_flame_lock);
+	buffer = d_alloc(sizeof(I_POINT)*10);
+	buffer_len = 10;
+	p = 0;
+	for ( a = aset->wa_list ; a ; a = a->next ) {
+		for ( ; ; ) {
+			gsize = (*a->tbl->get_interrested_point)(a,&buffer[p],buffer_len-p);
+			if ( gsize <= buffer_len-p )
+				break;
+			buffer_len += 10;
+			buffer = d_re_alloc(buffer,sizeof(I_POINT)*buffer_len);
+		}
+		p += gsize;
+	}
+	buffer_len = p;
+	(*move_func)(buffer,buffer_len,work);
+	p = 0;
+	for ( a = aset->wa_list ; a ; a = a->next ) {
+		p += (*a->tbl->set_interrested_point)(a,&buffer[p]);
+	}
+	unlock_task(gbview_flame_lock,"");
+}
+
+void
+wf_work_area_flush(WF_WORK_AREA_SET * aset)
+{
+WF_WORK_AREA * a;
+	lock_task(gbview_flame_lock);
+	for ( a = aset->wa_list ; a ; a = a->next )
+		(*a->tbl->flush_area)(a);
+	unlock_task(gbview_flame_lock,"");
+}
+
+WF_WORK_AREA_SET *
+wf_new_work_area_set()
+{
+WF_WORK_AREA_SET * ret;
+	ret = d_alloc(sizeof(*ret));
+	ret->checkout = 0;
+	ret->wa_list = 0;
+	ret->freeflag = 0;
+	return ret;
+}
+
+void
+wf_checkout_work_area_set(WF_WORK_AREA_SET * aset)
+{
+	lock_task(gbview_flame_lock);
+	aset->checkout ++;
+	unlock_task(gbview_flame_lock,"");
+	return;
+}
+
+void
+wf_checkin_work_area_set(WF_WORK_AREA_SET * aset)
+{
+	lock_task(gbview_flame_lock);
+	aset->checkout --;
+	if ( aset->checkout < 0 )
+		er_panic("wf_checkin_work_Area_set");
+	if ( aset->checkout == 0 && aset->freeflag ) {
+		_wf_close_work_area_set(aset);
+		d_f_ree(aset);
+	}
+	unlock_task(gbview_flame_lock,"");
+}
+
+
+void
+wf_mouse_mode(GBVIEW_FLAME * gf,int mode,I_POINT ptr,INTEGER64 tim)
+{
+RADAR_CACHE * rc;
+	if ( gf == 0 )
+		return;
+	rc = (RADAR_CACHE*)gf->radar_ptr;
+	rc_set_mouse_mode(rc,mode,ptr,tim);
+}
+
+
 
