@@ -34,6 +34,10 @@ init_genExit(XLISP_ENV * env)
 XL_SEXP *
 genExit(XLISP_ENV * env,XL_SEXP * s)
 {
+int iid;
+  	iid = get_main_interpreter();
+	if ( iid >= 0 )
+		close_interpreter(iid);
 	return get_error(
 		s->h.file,
 		s->h.line,
