@@ -24,6 +24,7 @@
 #include	"utils.h"
 #include	"gb.h"
 #include	"mx.h"
+#include	"fa_cache.h"
 
 
 int
@@ -34,12 +35,15 @@ _main(int argc,char ** argv)
 	init_l_favt64();
 	int_handler = 0;
 
+	gc_push(0,0,"main");
 	init_matrix();
 
 	init_gbs();
+	gc_pop(0,0);
 
 	init_function(gblisp_top_env0,gblisp_top_env1,argc,argv);
 	init_gmx_function(gblisp_top_env0,gblisp_top_env1);
+//	fac_general_info.total_entries = 0;
 
 	xl_setup_file(argc,argv);
 
