@@ -933,6 +933,9 @@ XL_SEXP * filename;
 extern L_CHAR * agent_name;
 XL_SEXP * ret,* sym;
 	filename = get_el(s,1);
+	ret = auth_filepath_passive(filename,"Set");
+	if ( get_type(ret) == XLT_ERROR )
+		return ret;
 
 	ptr = l_strlen(filename->string.data)-1;
 	for ( ; ptr >= 0 ; ptr -- ) {
