@@ -2261,6 +2261,9 @@ RESOURCE * locked_r;
 		if ( mode == GVHA_MODE_RSS_SHORT )
 			goto simple;
 
+		if ( r->h.type != RT_DRAW_GB )
+			goto simple;
+
 		if ( r != locked_r ) {
 			if ( locked_r )
 				unlock_pdb_lock(locked_r);
@@ -2869,8 +2872,21 @@ CODE_METHOD * cm;
 	cm = search_cm("UTF-8");
 	if ( cm == 0 )
 		er_panic("aa");
-	lock_pdb_lock(vs->vct,0);
+#ifdef GVHA_PATH_DEBUG
+ss_printf("obj-1 %p\n",vs->vct);
+#endif
+	if ( lock_pdb_lock(vs->vct,0) < -1 ) {
+		sts->status = GVHA_STS_OK;
+		sts->err_message = List(n_get_symbol("gvha-object"),-1);
+		goto end2;
+	}
+#ifdef GVHA_PATH_DEBUG
+ss_printf("obj-2\n");
+#endif
 	obj = search_obj(vs->vct,code);
+#ifdef GVHA_PATH_DEBUG
+ss_printf("obj-3\n");
+#endif
 	if ( obj == 0 ) {
 		sts->status = GVHA_STS_NO_OBJECT;
 		goto end;
@@ -2879,7 +2895,7 @@ CODE_METHOD * cm;
 	if ( obj->h.info_org == 0 ) {
 		sts->err_message = List(n_get_symbol("gvha-object"),-1);
 	}
-	if ( obj->h.info_card == 0 )
+	else if ( obj->h.info_card == 0 )
 		sts->err_message = List(n_get_symbol("gvha-object"),
 				convert_code(obj->h.info_org,cm->main_code,CBF_ERR_QUESTION),
 				-1);
@@ -2891,6 +2907,7 @@ CODE_METHOD * cm;
 			-1);
 end:
 	unlock_pdb_lock(vs->vct);
+end2:	;
 }
 
 void
@@ -2992,7 +3009,7 @@ GVHA_VCT_SET vs;
 CODE_METHOD * cm;
 GB_RECT o_rect1;
 GVHA_SET * g_set;
-
+int err;
 
 	memset(&q,0,sizeof(q));
 	sts_load = 0;
@@ -3003,7 +3020,7 @@ GVHA_SET * g_set;
 	if ( _dir == 0 )
 		goto sys_error;
 	g_set = search_gvha_set_URL(_dir);
-ss_printf("g_set = %p\n",g_set);
+ss_printf("g_set = %p Rls\n",g_set,_dir);
 	if ( g_set == 0 )
 		goto sys_error2;
 	_dir_1 = ln_copy_str(std_cm,_dir);
@@ -3016,6 +3033,10 @@ ss_printf("g_set = %p\n",g_set);
 		err_msg = "query parsing";
 		goto invalid_url;
 	}
+	if ( q.mode == GVHA_MODE_MOVE && q.pos.target == 0 ) {
+		err_msg = "query parsing target=0 mode undef";
+		goto invalid_url;
+	}
 	if ( q.mode & GVHA_NREQ_FRAME_CACHE ) {
 		c = 0;
 		goto finish2;
@@ -3112,12 +3133,24 @@ q.pos.target);
 #endif
 
 	flush_pos = 1;
-	rc_warp((RADAR_CACHE*)c->gf->radar_ptr,
+	err = rc_warp((RADAR_CACHE*)c->gf->radar_ptr,
 		WT_CENTER,0,
 		&q.pos.center,
 		q.pos.resolution,
 		q.pos.rotate,
 		q.pos.target,0,1);
+		
+#ifdef GVHA_PATH_DEBUG
+ss_printf("POS-AFTER (%f %f) %f %f --- %i\n",
+c->gf->flame_base_center.x,
+c->gf->flame_base_center.y,
+c->gf->flame_base_resolution,
+c->gf->flame_base_rotate,
+err);
+if ( c->gf->flame_base )
+ss_printf("POS-AFTER2 %ls\n",get_url_str2(&c->gf->flame_base->draw->h.entry));
+#endif
+
 change_layer:
 
 #ifdef GVHA_PATH_DEBUG
@@ -3327,7 +3360,13 @@ ss_printf("\n");
 		}
 		gs.err_message = get_integer(m_code,0);
 	insert_end:
+#ifdef GVHA_PATH_DEBUG
+ss_printf("insert_end 1\n");
+#endif
 		ret = return_gvha_status(&gs);
+#ifdef GVHA_PATH_DEBUG
+ss_printf("insert_end 2\n");
+#endif
 		break;
 	case GVHA_MODE_ECT_DELETE:
 		memset(&gs,0,sizeof(gs));
@@ -3411,11 +3450,23 @@ ss_printf("\n");
 		ret = return_gvha_status(&gs);
 		break;
 	case GVHA_MODE_ECT_OBJECT:
+#ifdef GVHA_PATH_DEBUG
+ss_printf("GVHA_MODE_ECT_OBJECT\n");
+#endif
 		memset(&gs,0,sizeof(gs));
 		get_gvha_vct(g_set,&gs,&vs,q.e_vct,q.e_vct_byname);
+#ifdef GVHA_PATH_DEBUG
+ss_printf("GVHA_MODE_ECT_OBJECT 2\n");
+#endif
 		if ( gs.status )
 			goto insert_end;
+#ifdef GVHA_PATH_DEBUG
+ss_printf("GVHA_MODE_ECT_OBJECT 3\n");
+#endif
 		gvha_object(&gs,&vs,q.e_objCode);
+#ifdef GVHA_PATH_DEBUG
+ss_printf("GVHA_MODE_ECT_OBJECT 4\n");
+#endif
 		goto insert_end;
 	default:
 		er_panic("xl_GET");
