@@ -68,9 +68,11 @@ printf("GBVIEW %i\n",get_xltime());
 	sts.flags = SF_RADAR;
 	wf_set_status(gf,&sts);
 */
+	gc_push(0,0,"main");
 
 	init_gbview_function(gblisp_top_env0, gblisp_top_env1);
 	init_WritingStyle(gblisp_top_env0);
+	gc_pop(0,0);
 /*
 	if ( argc < 2 ) {
 		printf("too few arguments\n");
