@@ -30,8 +30,8 @@
 #define STAT_LEN		2
 #define STAT_TICK		11
 #define NCACHE_RATE		10
-#define MAX_OPEN_FILES_FOR_MX	10
-#define MLOCK_LIFE_TIME		30
+#define MAX_OPEN_FILES_FOR_MX	500
+#define MLOCK_LIFE_TIME		300
 #define DIRTY_LIMIT		30
 #define RING_GC_INTERVAL_LONG	120
 #define RING_GC_INTERVAL_SHORT	2
@@ -902,6 +902,7 @@ int write_mx_cache(MX_CACHE_PARAM * p);
 int read_mx_cache(MX_CACHE_PARAM * p);
 int read_mx_cache_vector(MX_CACHE_PARAM * p);
 int write_mx_cache_vector(MX_CACHE_PARAM * p);
+void mxc_close(MX_CACHE * c);
 
 MX_DIM_CODE_LIST *
 mx_search_level_node(MATRIX * m,INTEGER64 * last_dc,int limit);
@@ -1041,5 +1042,7 @@ void
 init_mxObjID(XLISP_ENV * env);
 
 
+extern int mx_cache_error;
+
 #endif
 
