@@ -39,7 +39,7 @@
 #define RADAR_RESO_PTR_SIZE		8
 
 #define WIN_RESO_WINDOW_MIN		2
-#define WIN_RESO_WINDOW_MAX		4000
+#define WIN_RESO_WINDOW_MAX		8000
 
 #define GLOBE_RESO_LIMIT		800
 
@@ -239,6 +239,7 @@ typedef struct warp_point {
 #define WPT_SIMPLE		0x00000001
 #define WPT_CRD			0x00000002
 #define WPT_ONLY_ACTIVE		0x00000004
+#define WPT_TARGET		0x00000008
 	L_CHAR *		title;
 	INTEGER64		tracking_time;
 	QUERY_THREAD *		qth;
@@ -307,6 +308,8 @@ typedef struct radar_cache {
 #define TMM_REMK	(1<<TM_REMK)
 #define TMM_INS		(1<<TM_INS)
 
+	int			dim;
+
 	RADAR_HISTORY *		history;
 	RADAR_HISTORY *		history_ptr;
 	Q_THREAD_LIST *		q_thread_tmp;
@@ -365,6 +368,22 @@ typedef struct radar_cache {
 
 	float			recommend_interval;
 	INTEGER64		last_access_loading;
+	
+	
+	XLISP_ENV *		session_env;
+	STREAM *		session_stream;
+
+	int			mouse_mode;
+#define RD_MOUSE_IDLE		0
+#define RD_MOUSE_CLICK		0x02
+#define RD_MOUSE_DOUBLE		0x04
+#define RD_MOUSE_DOUBLE_FLOAT	0x08
+#define RD_MOUSE_DRAG		0x10
+#define RD_MOUSE_ZOOM_IN	0x20
+#define RD_MOUSE_ZOOM_OUT	0x40
+#define RD_MOUSE_ROTATE		0x80
+	I_POINT			mouse_point;
+	INTEGER64		mouse_time;
 
 	struct radar_cache *	next;
 } RADAR_CACHE;
@@ -461,7 +480,10 @@ rc_set_condition_event(
 	void*work);
 
 QUERY_THREAD *sexp_to_q_thread(XL_SEXP *);
-void free_query_thread(QUERY_THREAD*);
+void _xx_free_query_thread_1(RADAR_CACHE * rc_ptr,QUERY_THREAD * qt,char*,int);
+void xx_free_query_thread(QUERY_THREAD*,char*,int);
+#define _free_query_thread_1(rc_ptr,qt)	_xx_free_query_thread_1(rc_ptr,qt,__FILE__,__LINE__)
+#define free_query_thread(qt)	xx_free_query_thread(qt,__FILE__,__LINE__)
 
 /* NEW */
 	
@@ -569,7 +591,7 @@ int __clean_radar_matrix(RADAR_CACHE * rc_ptr,Q_THREAD_LIST * qt,RADAR_MATRIX *
 void _clean_force_matrix(RADAR_CACHE * rc_ptr,int clear_count);
 void clean_radar_matrix(RADAR_CACHE * rc_ptr,Q_THREAD_LIST * qt);
 int set_ptr_list(RADAR_CACHE * rc_ptr,int ses,RADAR_CRD * c);
-int _insert_radar_url(RADAR_CACHE * rc_ptr,int qt_id,int ses,L_CHAR * crd,L_CHAR * obj);
+int _insert_radar_url(RADAR_CACHE * rc_ptr,int qt_id,int ses,L_CHAR * crd,L_CHAR * obj,int wup_flag);
 int remake_cache(RADAR_CACHE * rc_ptr,int ses,int type,WF_ID current,WF_ID next);
 int cmp_wf_crd(CRD_LIST * c1,CRD_LIST * c2);
 AVT_NODE * get_wf_tree(RADAR_CACHE * rc_ptr);
@@ -596,14 +618,14 @@ void query_trigger2(RADAR_CACHE * rc_ptr);
 int __include_query_check(XL_SEXP * rc_q,XL_SEXP * q);
 int _include_query_check(XL_SEXP * rc_q,XL_SEXP * q);
 XL_SEXP * include_query_check(XL_SEXP * rc_query,XL_SEXP * query);
-RADAR_CACHE * get_sf_rc_ptr(XL_SYM_FIELD * sf);
+RADAR_CACHE * get_sf_rc_ptr(XLISP_ENV * env,XL_SYM_FIELD * sf);
 int beam_convert(int ses,L_CHAR * burl,RADAR_LUMP * rl,
 		GB_RECT * r,REAL1 * min,REAL1 * max,
 		L_CHAR ** unit_p,L_CHAR ** r_unit_p);
 void test_lock(int f);
 RADAR_LUMP * merge_radar_lump(RADAR_LUMP * rl,RADAR_LUMP * rl2);
 void beam_to_remote(RADAR_CACHE * rc_ptr,
-	int ses,GB_RECT * r,REAL1 min,REAL1 max,XL_SEXP * q,int qt_id);
+	int ses,GB_RECT * r,REAL1 min,REAL1 max,XL_SEXP * q,int qt_id,int insert_que_flag);
 int insert_check(SYS_QUEUE * q,T_RESOURCE_TO_INSERT * n,L_CHAR * obj_url);
 void beam_load(RADAR_CACHE * rc_ptr,XL_SEXP * lst,int qt_id);
 XL_SEXP * beam_to_lump(RADAR_CACHE * rc_ptr,int ses,GB_RECT * r,REAL1 min,REAL1 max,int id);
@@ -671,7 +693,6 @@ void _rc_set_condition_event(
 	void*work);
 int copy_ri(RADAR_INDICATE * ri1,RADAR_INDICATE * ri2);
 
-void _free_query_thread_1(RADAR_CACHE * rc_ptr,QUERY_THREAD * qt);
 int  q_thread_id_len(int * id_list);
 int * insert_q_thread_id(int * id_list,int id);
 Q_THREAD_LIST ** 
@@ -754,6 +775,18 @@ rc_copy_warp_point(WARP_POINT * wp);
 int 
 rc_trackback(XL_SEXP ** retp,RADAR_CACHE * rc_ptr,L_CHAR * path);
 
+WARP_POINT *
+rc_eurl2wp(L_CHAR * url);
+int
+rc_close_session(RADAR_CACHE * rc_ptr);
+int
+_rc_close_session(RADAR_CACHE * rc_ptr);
+int
+rc_get_mouse_mode(RADAR_CACHE * rc_ptr,int * mode,I_POINT * ptr,INTEGER64 * tim,int flags,int wait_flag);
+int
+rc_set_mouse_mode(RADAR_CACHE * rc_ptr,int mode,I_POINT ptr,INTEGER64 tim);
+
+
 
 #endif
 
