@@ -443,7 +443,7 @@ typedef struct coordinate {
 #define GT_D_SHIFT		16
 #define GT_A_SHIFT		0
 
-#define GT_T_MAX		3
+#define GT_T_MAX		4
 #define GT_D_MAX		4
 
 #define GT_T_MASK		0xff000000
@@ -452,6 +452,7 @@ typedef struct coordinate {
 
 #define GT_T_2D			0x01000000
 #define GT_T_GLOBE_SUR		0x02000000
+#define GT_T_1D			0x03000000
 #define GT_D_PITAGOLAS 		0x00010000
 #define GT_D_GLOBE		0x00020000
 #define GT_D_ELLIPSOID		0x00030000
@@ -465,6 +466,7 @@ typedef struct coordinate {
 #define GT_A_COMP		(GT_A_X_FOR|GT_A_Y_REV)
 
 #define GT_E2D		(GT_T_2D|GT_D_PITAGOLAS)
+#define GT_E1D		(GT_T_1D|GT_D_PITAGOLAS)
 #define GT_ELLIPSOID	(GT_T_GLOBE_SUR|GT_D_ELLIPSOID)
 	double *	geometory_param;
 
@@ -761,6 +763,7 @@ typedef struct draw_work {
 	int			data_request;
 	int			draw_code;
 	
+	void *			work;
 } DRAW_WORK;
 
 
@@ -1087,7 +1090,7 @@ int get_fi(REAL1 * ret,XL_SEXP * d);
 void load_parents(RESOURCE * r,XL_SEXP * s);
 int get_cid_from_sexp(COORDINATE * c,XL_SEXP * cid);
 XL_SEXP * gv_new_coordinate(RESOURCE * r,XL_SEXP * s,int ds);
-void load_coordinate_option();
+void load_coordinate_option(RESOURCE *);
 
 void free_mapping_from_sd(RESOURCE * src,RESOURCE * dest);
 void init_luster();
