@@ -432,7 +432,7 @@ CALL_LOCK_DESCRIPTER cl_invalid();
 void init_xl(int);
 void init_function(XLISP_ENV *,XLISP_ENV *,int,char **);
 XL_INTERPRETER * xx_new_xl_interpreter(char*,int);
-#define new_xl_interpreter()	xx_new_xl_interpreter(__FILE__,__LINE__);
+#define new_xl_interpreter()	xx_new_xl_interpreter((char*)__FILE__,__LINE__);
 void init_xl_interpreter(XL_INTERPRETER * xs);
 void put_xl_fifo(XL_INTERPRETER *,XL_SEXP *);
 XL_SEXP * get_xl_fifo(XL_INTERPRETER *,int);
@@ -442,7 +442,7 @@ int check_fifo(XL_INTERPRETER *);
 void close_xl_fifo(XL_INTERPRETER *);
 int return_result(XL_INTERPRETER *,XL_SEXP *);
 XL_SEXP * remote_query(int,XLISP_ENV *,L_CHAR *,XL_SEXP *);
-XL_SEXP * local_query(XLISP_ENV *,L_CHAR *,XL_SEXP *);
+XL_SEXP * local_query(XLISP_ENV *,XL_INTERPRETER*,L_CHAR *,XL_SEXP *);
 XL_SEXP * local_eval(int seq_no,XL_SEXP * cmd_sexp);
 int setup_i(XL_INTERPRETER*);
 
@@ -504,6 +504,9 @@ int open_session(int type);
 //#define SEST_DIRECT	2
 int aboat_session(XL_SEXP * s);
 
+void replace_agent(L_CHAR *,L_CHAR*,L_CHAR * agent);
+void delete_replace_agent(L_CHAR *,L_CHAR*);
+
 void close_session(int);
 XL_SEXP *
 remote_session(
@@ -537,7 +540,7 @@ log_print_sexp(
 	int level,
 	int layer,
 	LOG_NODE_DATA *,
-	char * str,
+	const char * str,
 	XL_SEXP * s,
 	int flags);
 L_CHAR get_proper_code(XL_SEXP *,int);
