@@ -946,16 +946,18 @@ struct ft2_font_coverage_t *arg = (struct ft2_font_coverage_t*)a;
 FT2_FONTREC * fr;
 int err;
 int i;
-
 	fr = arg->fr;
 	for ( i = 0 ; i < fr->work_face->num_charmaps ; i ++ ) {
 		if ( fr->encode_info[i].coverage )
 			continue;
 		err = FT_Select_Charmap(fr->work_face, 
 			fr->work_face->charmaps[i]->encoding);
-		if ( err )
-			er_panic(">>>");
-		fr->encode_info[i].coverage = ft2_get_coverage(fr);
+		fr->encode_info[i].err = err;
+		if ( err ) {
+			ss_printf("COVERAGE FONT ERROR %ls %ls\n",fr->family,fr->style);
+			fr->encode_info[i].coverage = 0;
+		}
+		else	fr->encode_info[i].coverage = ft2_get_coverage(fr);
 		
 	}
 	return 0;
@@ -992,12 +994,16 @@ FT2_ENCODE_INFO * ei;
 					continue;
 			}
 			ei = &fr->encode_info[0];
+			if ( ei->err )
+				continue;
 			if ( ei->coverage == 0 ) {
 				arg.fr = fr;
 				ft2_do(
 					_ft2_font_coverage,
 					&arg);
 			}
+			if ( ei->err )
+				continue;
 			for ( j = 0 ; j < 
 				fr->work_face->num_charmaps ; j ++ ) {
 				ei = &fr->encode_info[j];
