@@ -745,15 +745,23 @@ FAVT64_NODE * g;
 }
 
 
+int depth_min = 0x7fffffff;
+int depth_max;
+INTEGER64 pr_time;
+
 FAVT64_NODE *
 favt64_search(int * errp,
 	FAVT64_ROOT * p,FAVT64_NODE * a,void * data,int (*cmp)(),void * w)
 {
 FAVT64_NODE * b;
+
+int depth;
+INTEGER64 tim;
 	touch_ring64(p,a);
 	if ( a )
 		favt64_lock(&a->h);
-	for ( ; a ; ) {
+	depth = 0;
+	for ( ; a ; depth ++ ) {
 		switch ( (*cmp)(a->data,data,w) ) {
 		case -1:
 			b = large_node64(errp,p,a);
@@ -763,6 +771,21 @@ FAVT64_NODE * b;
 			a = b;
 			break;
 		case 0:
+			if ( a->large.fofs == 0 && a->small.fofs == 0 ) {
+				tim = get_xltime();
+				if ( depth_min > depth )
+					depth_min = depth;
+				if ( depth_max < depth )
+					depth_max = depth;
+/*
+				if ( pr_time != tim ) {
+					pr_time = tim;
+					ss_printf("DEPTH = %i - %i %i\n",
+						depth,depth_max,depth_min);
+	
+				}
+*/
+			}
 			favt64_unlock(&a->h);
 			return a;
 		case 1:
