@@ -70,7 +70,7 @@ int e_type;
 			src->floating = 1;
 			w->floating = 1;
 		}
-		else	sscanf(n_string(std_cm,x->string.data),"%f",&src->ptr.x);
+		else	sscanf(n_string(std_cm,x->string.data),REAL1_F,&src->ptr.x);
 		break;
 	case XLT_NULL:
 		src->ptr.x = 0;
@@ -94,7 +94,7 @@ int e_type;
 			src->floating = 1;
 			w->floating = 1;
 		}
-		else	sscanf(n_string(std_cm,y->string.data),"%f",&src->ptr.y);
+		else	sscanf(n_string(std_cm,y->string.data),REAL1_F,&src->ptr.y);
 		break;
 	case XLT_NULL:
 		src->ptr.y = 0;
@@ -363,7 +363,7 @@ L_CHAR * n;
 	for ( ; ; ) {
 		if ( fgets(buffer,1000,fd) == 0 )
 			break;
-		sscanf(buffer,"%s\t%i\t%f\t%f\n",
+		sscanf(buffer,"%s\t%i\t" REAL1_F "\t" REAL1_F "\n",
 			pname,&f,&ptr.x,&ptr.y);
 		n = l_string(std_cm,pname);
 		for ( v = w->vertex ; v ; v = v->next )
@@ -664,8 +664,13 @@ int i;
 	for ( v = w->vertex ; v ; v = v->next ) {
 		if ( v->src_list->floating == 0 )
 			continue;
-		if ( distance(w->center,plist[i]) > w->radius )
+		if ( distance(w->center,plist[i]) > w->radius ) {
+			ss_printf("CENTER %f %f - %f %f - %f\n",
+				w->center.x,w->center.y,
+				plist[i].x,plist[i].y,
+				w->radius);
 			er_panic("STORE OVER\n");
+		}
 		v->src_list->ptr = plist[i++];
 	}
 }
@@ -1343,7 +1348,7 @@ ss_printf("OPT START\n");
 	w->center.y *= 0.5;
 	len  = 0;
 	pitch = ((r.br.x - r.tl.x) + (r.br.y - r.tl.y))/2;
-	w->radius = pitch*10;
+	w->radius = pitch*20;
 	w->max_dist = pitch*2;
 	w->dist = 0;
 	w->dist_cnt = 0;
