@@ -69,6 +69,7 @@ int resolve_running = 0;
 
 #define DEL_SIZE	100
 #define RESOLV_TICK	3600
+#define RESOLV_TICK_ERR	30
 #define RESOLV_TIMEOUT		600
 #define RESOLV_QUE_TIMEOUT	120
 #define RESOLV_MIN_TIMEOUT	2
@@ -89,7 +90,8 @@ int _return_host_entry(HOST_ENTRY*,char * name,HOST_ADDR*);
 HOST_ENTRY * resolve_request(HOST_ADDR * a,char * name);
 
 void resolve_thread();
-int resolve_tid;
+void * resolve_func_work;
+void (*resolve_func)(void*);
 int resolve_launch;
 RESOLVE_REQUEST_T * resolve_que_head;
 RESOLVE_REQUEST_T * resolve_que_tail;
@@ -146,6 +148,20 @@ RESOLVE_QUEUE_HEADER * h;
 }
 
 
+void
+aboat_resolve_request()
+{
+void (*func)(void*);
+void * tid;
+	if ( resolve_running ) {
+		printf("ABOAT RESOLVE\n");
+		func = resolve_func;
+		tid = resolve_func_work;
+		if ( func )
+			(*func)(tid);
+	}
+}
+
 void
 _wakeup_resolve_thread()
 {
@@ -548,17 +564,32 @@ _return_host_entry(HOST_ENTRY * he,char * name,HOST_ADDR * ap)
 }
 
 
+void
+set_resolve_abort(void (*func)(void*),void* tid)
+{
+	if ( resolve_func ) {
+		resolve_func_work = tid;
+		resolve_func = func;
+	}
+	else {
+		resolve_func = 0;
+		resolve_func_work = 0;
+	}
+}
+
 
 void
 resolve_thread()
 {
 RESOLVE_REQUEST_T * n;
 
+/*
 	resolve_tid = get_tid();
+*/
 	for ( ; ; ) {
 		lock_task(resolve_lock2);
 		if (  resolve_que_head == 0 ) {
-			resolve_tid = 0;
+			resolve_func_work = 0;
 			resolve_launch = 0;
 			unlock_task(resolve_lock2,"resolve_thread");
 //			sleep_task((int)&resolve_tid,resolve_lock2);
@@ -635,7 +666,7 @@ ss_printf("Y\n");
 		resolve_launch = 1;
 		create_task((void(*)(TKEY))resolve_thread,PRI_FETCH,0);
 	}
-	else wakeup_task((int)&resolve_tid);
+	else wakeup_task((int)&resolve_func_work);
 
 #ifdef RESOLVE_DEBUG
 ss_printf("WAIT LOOP %i\n",get_tid());
@@ -723,10 +754,11 @@ retry:
 */
 	}
 ok:
-	if ( ret )
-		ret->access = t;
-	if ( ret->flags & HEF_ERROR )
-		ret = 0;
+	if ( ret ) {
+		if ( ret->flags & HEF_ERROR )
+			ret = 0;
+		else	ret->access = t;
+	}
 	unlock_task(resolve_lock2,"r_gethostbyaddr");
 	return ret;
 }
@@ -804,10 +836,11 @@ retry:
 */
 	}
 ok:
-	if ( ret )
-		ret->access = t;
-	if ( ret->flags & HEF_ERROR )
-		ret = 0;
+	if ( ret ) {
+		if ( ret->flags & HEF_ERROR )
+			ret = 0;
+		else	ret->access = t;
+	}
 	unlock_task(resolve_lock2,"r_gethostbyname");
 #ifdef RESOLVE_DEBUG
 ss_printf("r_get_hostbyname :: %s OK\n",name);
@@ -827,7 +860,13 @@ retry:
 	for ( he = resolv_cache ; he ; he = he->next ) {
 		if ( he->flags & HEF_LOGHOST )
 			continue;
-		if ( t - he->access > RESOLV_TICK ) {
+		if ( he->flags & HEF_ERROR ) {
+			if ( t - he->access > RESOLV_TICK_ERR ) {
+				_delete_host_entry(he);
+				goto retry;
+			}
+		}
+		else if ( t - he->access > RESOLV_TICK ) {
 			_delete_host_entry(he);
 			goto retry;
 		}
