@@ -59,8 +59,8 @@ init_tick()
 {
 
 	tick_lock = new_lock(LL_TICK);
-	create_task(tick_thread,0,PRI_TICK);
-	create_task(tick_thread_2,0,PRI_TICK_STRONG);
+	create_task((void(*)(TKEY))tick_thread,0,PRI_TICK);
+	create_task((void(*)(TKEY))tick_thread_2,0,PRI_TICK_STRONG);
 }
 
 void
