@@ -1,4 +1,4 @@
-/* ver.B.b13(BLAZE) */
+/* ver.B.b17.02(BLAZE) */
 
 
 #include "version.h"
@@ -7,9 +7,9 @@
 VERSION ap_version = {
 	"AP.code",
 	"cosmos",
-	"(C) 2000-2005 Hirohisa Mori",
-	"ver.B.b13(BLAZE)",
-	2006,10,17,
+	"(C) 2000-2007 Hirohisa Mori and GLOBALBASE Project",
+	"ver.B.b17.02(BLAZE)",
+	2008,3,16,
 	0,
 	"cosmos GLOBALBASE viewer ",
 };
