@@ -1,4 +1,4 @@
-/* ver.B.b16.04(BLAZE) */
+/* ver.B.b17(BLAZE) */
 
 
 #include "version.h"
@@ -8,8 +8,8 @@ VERSION ap_version = {
 	"AP.code",
 	"nig2svg",
 	"(C) 2000-2007 Hirohisa Mori and GLOBALBASE Project",
-	"ver.B.b16.04(BLAZE)",
-	2007,6,4,
+	"ver.B.b17(BLAZE)",
+	2008,1,11,
 	0,
 	"nigmas to svg format converter ",
 };
