@@ -1,4 +1,4 @@
-/* ver.B.b14(BLAZE) */
+/* ver.B.b17.01(BLAZE) */
 
 
 #include "version.h"
@@ -7,9 +7,9 @@
 VERSION ap_version = {
 	"AP.code",
 	"xlufr",
-	"(C) 2000-2007 Hirohisa Mori",
-	"ver.B.b14(BLAZE)",
-	2007,2,10,
+	"(C) 2000-2007 Hirohisa Mori and GLOBALBASE Project",
+	"ver.B.b17.01(BLAZE)",
+	2008,1,11,
 	0,
 	"GLOBALBASE File Access Grue ",
 };
