@@ -127,6 +127,7 @@ VMenuItem::VMenuItem(VMenuItem& menu, VMenuBar *menu_bar)
 	}
 }
 
+
 VMenuItem::~VMenuItem()
 {
 	if ( name )
@@ -446,16 +447,16 @@ V_CALLBACK_D(VMenuBar::refresh_menu_bar)
 int category;
 	if ( window_list == 0 )
 		return;
-	VCustomizedMenuBar::menu_lock(__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_lock((char*)__FILE__,__LINE__);
 	category = (int)user_arg;
 	window_list->refresh_menu_bar(category);
-	VCustomizedMenuBar::menu_unlock(__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_unlock((char*)__FILE__,__LINE__);
 }
 
 void
 VMenuBar::refresh_menu_bar(int category)
 {
-	vq_insert_callback(0,refresh_menu_bar,(void*)category,0,0,0);
+	vq_insert_callback_machine(0,refresh_menu_bar,(void*)category,0,0,0,0);
 }
 
 VCustomizedMenuBar *
@@ -570,11 +571,11 @@ V_CALLBACK_D(VCustomizedMenuBar::set_menu_flag_que)
 SET_MENU_T * sm;
 VCustomizedMenuBar * mb;
 	sm = (SET_MENU_T*)user_arg;
-	menu_lock(__FILE__,__LINE__);
+	menu_lock((char*)__FILE__,__LINE__);
 	mb = sm->win->get_menu_bar();
 	if ( mb )
 		mb->set_menu_flag(sm->id,sm->flag);
-	menu_unlock(__FILE__,__LINE__);
+	menu_unlock((char*)__FILE__,__LINE__);
 	d_f_ree(sm);
 }
 
@@ -586,7 +587,7 @@ SET_MENU_T * sm;
 	sm->id = id;
 	sm->flag = flag;
 	sm->win = win;
-	vq_insert_callback(0,set_menu_flag_que,sm,0,0,0);
+	vq_insert_callback_machine(0,set_menu_flag_que,sm,0,0,0,0);
 }
 
 V_CALLBACK_D(VCustomizedMenuBar::set_menu_func_que)
@@ -594,11 +595,11 @@ V_CALLBACK_D(VCustomizedMenuBar::set_menu_func_que)
 SET_MENU_T * sm;
 VCustomizedMenuBar * mb;
 	sm = (SET_MENU_T*)user_arg;
-	menu_lock(__FILE__,__LINE__);
+	menu_lock((char*)__FILE__,__LINE__);
 	mb = sm->win->get_menu_bar();
 	if ( mb )
 		mb->set_menu_func(sm->id,sm->func,sm->data);
-	menu_unlock(__FILE__,__LINE__);
+	menu_unlock((char*)__FILE__,__LINE__);
 	d_f_ree(sm);
 }
 
@@ -611,7 +612,7 @@ SET_MENU_T * sm;
 	sm->func = func;
 	sm->data = data;
 	sm->win = win;
-	vq_insert_callback(0,set_menu_func_que,sm,0,0,0);
+	vq_insert_callback_machine(0,set_menu_func_que,sm,0,0,0,0);
 }
 
 V_CALLBACK_D(VCustomizedMenuBar::set_menu_name_que)
@@ -619,11 +620,11 @@ V_CALLBACK_D(VCustomizedMenuBar::set_menu_name_que)
 SET_MENU_T * sm;
 VCustomizedMenuBar * mb;
 	sm = (SET_MENU_T*)user_arg;
-	menu_lock(__FILE__,__LINE__);
+	menu_lock((char*)__FILE__,__LINE__);
 	mb = sm->win->get_menu_bar();
 	if ( mb )
 		mb->set_menu_name(sm->id,sm->name);
-	menu_unlock(__FILE__,__LINE__);
+	menu_unlock((char*)__FILE__,__LINE__);
 	d_f_ree(sm->name);
 	d_f_ree(sm);
 }
@@ -636,7 +637,7 @@ SET_MENU_T * sm;
 	sm->id = id;
 	sm->name = name;
 	sm->win = win;
-	vq_insert_callback(0,set_menu_name_que,sm,0,0,0);
+	vq_insert_callback_machine(0,set_menu_name_que,sm,0,0,0,0);
 }
 
 
@@ -651,9 +652,14 @@ VCustomizedMenuBar::menu_choosed(VMenuItem *item)
 			return true;
 	
 	if ( item && item->func ) {
-		VCustomizedMenuBar::menu_lock(__FILE__,__LINE__);
+#ifdef MENU_ITEM_INHERIT
+		VCustomizedMenuBar::menu_lock((char*)__FILE__,__LINE__);
 		item->i_tid = VCustomizedMenuBar::menu_lock_inheritance_from();
 		vq_insert_callback(window, item->func, item, 0, 0,0);
+#else
+printf("FUNC = %p\n",item->func);
+		vq_insert_callback_machine(window, item->func, item, 0, 0,0 ,&item->i_tid);
+#endif
 		return true;
 	}
 	return false;
@@ -725,6 +731,8 @@ int tid;
 			wakeup_task((int)&_menu_lock);
 			menu_lock_tid = 0;
 		}
+		if ( inheritance_mode && menu_lock_cnt == 1 )
+			wakeup_task((int)&inheritance_mode);
 		menu_unlock_file = file;
 		menu_unlock_line = line;
 		unlock_task(_menu_lock,"menu_unlock");
@@ -758,6 +766,10 @@ int tid;
 		er_panic("menu_lock_inheritance");
 	if ( itid != inheritance_mode )
 		er_panic("menu_lock_inheritance(2)");
+	for ( ; menu_lock_cnt > 1 ; ) {
+		sleep_task((int)&inheritance_mode,_menu_lock);
+		lock_task(_menu_lock);
+	}
 	inheritance_mode = 0;
 	if ( ms_unlock_func ) {
 		(*ms_inheritance_func)(itid,file,line);
