@@ -389,7 +389,7 @@ VObject::destroy()
 	for ( ; ; ) {
 		if ( ps.parent == 0 )
 			break;
-		err = ps.parent->lock_d(__FILE__,__LINE__);
+		err = ps.parent->lock_d((char*)__FILE__,__LINE__);
 		if ( err )
 			return V_ER_NO_ERR;
 		op = new VObjectList;
@@ -414,13 +414,13 @@ VObject::destroy()
 		}
 	}
 	for ( op2 = objs ; op2  ; op2 = op2->next ) {
-		err = op2->object->lock_d(__FILE__,__LINE__);
+		err = op2->object->lock_d((char*)__FILE__,__LINE__);
 		if ( err ) {
 			err = V_ER_NO_ERR;
 			goto error;
 		}
 	}
-	lock(this,__FILE__,__LINE__);
+	lock(this,(char*)__FILE__,__LINE__);
 	if ( destroy_time != V_OBJECT_ALIVE ) {
 		err = V_ER_NO_ERR;
 		goto error;
@@ -472,7 +472,7 @@ VExError err, err_s;
 	err = create_do(s, flags,nmp , arg);
 	if ( err.code )
 		return err;
-	lock(this,__FILE__,__LINE__);
+	lock(this,(char*)__FILE__,__LINE__);
 	v_object_hash_add(this, sts.id);
 	err_s = set_status(&v_default_sts, VSF_DEF_FLAGS & 
 				(~flags) &
@@ -796,7 +796,7 @@ VObject::get_nmc(int c)
 {
 VError err;
 VObject * ret;
-	err = lock_d(__FILE__,__LINE__);
+	err = lock_d((char*)__FILE__,__LINE__);
 	if ( err )
 		return 0;
 	if ( get_type() < VO_MACR && c == 0 ) {
@@ -1096,7 +1096,7 @@ VObject *VObject::create_tmp(VObject *(*new_object)(), unsigned obj_type, const
 		return 0;
 	}
 		
-	err2 = s->parent->lock_d(__FILE__,__LINE__);
+	err2 = s->parent->lock_d((char*)__FILE__,__LINE__);
 	if ( err2 ) {
 		if ( err )
 			*err = initial_VExError(err2,flags,VSF_PARENT);
@@ -1113,7 +1113,7 @@ VObject *VObject::create_tmp(VObject *(*new_object)(), unsigned obj_type, const
 	unlock(s->parent);
 
 	for ( ; ; ) {
-		err2 = ss.parent->lock_d(__FILE__,__LINE__);
+		err2 = ss.parent->lock_d((char*)__FILE__,__LINE__);
 		if ( err2 ) {
 			if ( err )
 				*err = initial_VExError(V_ER_DESTROYED,flags,VSF_PARENT);
@@ -1140,7 +1140,7 @@ VObject *VObject::create_tmp(VObject *(*new_object)(), unsigned obj_type, const
 		}
 	}
 	for ( op = objs->next ; op ; op = op->next ) {
-		err2 = op->object->lock_d(__FILE__,__LINE__);
+		err2 = op->object->lock_d((char*)__FILE__,__LINE__);
 		if ( err2 ) {
 			op2 = op;
 			if ( err )
