@@ -156,8 +156,9 @@ V_CALLBACK_D(vobj_menu_choosed)
 {
 int data;
 VSysArgTranslator vsat;
+
 	VMenuItem *item = (VMenuItem*)user_arg;
-	VCustomizedMenuBar::menu_lock_inheritance(item->i_tid,__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_lock_inheritance(item->i_tid,(char*)__FILE__,__LINE__);
 	int id = item->get_id();
 	VCustomizedMenuBar *bar = 
 		dynamic_cast<VCustomizedMenuBar*>(item->get_bar());
@@ -169,7 +170,7 @@ VSysArgTranslator vsat;
 	vsat.func = (L_CHAR*)func;
 	vsat.env = vobj_env;
 	vsat.translator = menu_translator;
-	VCustomizedMenuBar::menu_unlock(__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_unlock((char*)__FILE__,__LINE__);
 
 	if ( func ) {
 		vobj_callback_glue(win, (void*)&vsat, (void*)&data);
@@ -546,10 +547,10 @@ vobj_SetMenuStatus(XLISP_ENV *env, XL_SEXP *arg, XLISP_ENV *a, XL_SYM_FIELD *sf)
 	if ( get_type(v) && get_type(v) != XLT_STRING )
 		goto type_missmatch;
 	
-	VCustomizedMenuBar::menu_lock(__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_lock((char*)__FILE__,__LINE__);
 	mb = vwin->get_menu_bar();
 	if ( mb == 0 ) {
-		VCustomizedMenuBar::menu_unlock(__FILE__,__LINE__);
+		VCustomizedMenuBar::menu_unlock((char*)__FILE__,__LINE__);
 		goto object_type_missmatch;
 	}
 	
@@ -573,7 +574,7 @@ vobj_SetMenuStatus(XLISP_ENV *env, XL_SEXP *arg, XLISP_ENV *a, XL_SYM_FIELD *sf)
 		}
 	}
 		
-	VCustomizedMenuBar::menu_unlock(__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_unlock((char*)__FILE__,__LINE__);
 
 	if ( ! exec )
 		return vobj_get_error(initial_VExError(V_ER_PARAM,0,0), arg,0);
