@@ -173,7 +173,7 @@ VMacro::_vm_unlock()
 {
 int t;
 	t = get_tid();
-	_i_lock_task(VMacro_lock,__FILE__,__LINE__);
+	_i_lock_task(VMacro_lock,(char*)__FILE__,__LINE__);
 	if ( vmacro_task != t )
 		er_panic("vm_lock");
 	vmacro_lock_cnt --;
