@@ -37,6 +37,8 @@ XL_SEXP * gb_Neq();
 XL_SEXP * gb_lt();
 XL_SEXP * gb_geq();
 XL_SEXP * gb_gt();
+XL_SEXP *
+gb_shift(XLISP_ENV * e,XL_SEXP * s,XLISP_ENV * a,XL_SYM_FIELD * sf);
 
 extern SEM gb_env_lock;
 extern SEM parse_lock,lex_lock;
@@ -146,6 +148,8 @@ init_gblisp()
 		get_func_prim(gb_div,FO_APPLICATIVE,0,3,3));
 	set_env(gblisp_top_env0,l_string(std_cm,"div"),
 		get_func_prim(gb_div,FO_APPLICATIVE,0,3,3));
+	set_env(gblisp_top_env0,l_string(std_cm,"shift"),
+		get_func_prim(gb_shift,FO_APPLICATIVE,0,3,3));
 	set_env(gblisp_top_env0,l_string(std_cm,"rem"),
 		get_func_prim(gb_rem,FO_APPLICATIVE,0,3,3));
 	set_env(gblisp_top_env0,
