@@ -1400,7 +1400,12 @@ gb_read:
 {
 extern int test_gb;
 if ( test_gb )
-printf("+%c:%i / ",(char)ch,f->token_head_line);
+*/
+/*
+if ( ch <' ' )
+printf("+[%x]:%i-%i:%i / ",(int)ch,f->token_head_line,f->line,f->mode);
+else
+printf("+%c:%i-%i:%i / ",(char)ch,f->token_head_line,f->line,f->mode);
 }
 */
 	if ( (ch&LCZM_2B_TYPE) == LCZ_2BC_LCCODE ) {
