@@ -1554,7 +1554,7 @@ int gc_no;
 			List(n_get_symbol("quote"),ret,-1),
 			-1);
 //	ret = remote_query(xli->id,gblisp_top_env0,0,auth);
-	ret = local_query(gblisp_top_env0,0,auth);
+	ret = local_query(gblisp_top_env0,0,0,auth);
 	if ( get_type(ret) != XLT_ERROR ) {
 		ret = ap_server_authentification(xli->auth_c_set,ret,path->string.data,operation);
 	}
