@@ -42,7 +42,9 @@ submain(int argc,char ** argv)
 
 	init_xl(INI_DONTWAITCHI);
 
+	gc_push(0,0,"main");
 	init_function(gblisp_top_env0,gblisp_top_env1,argc,argv);
+	gc_pop(0,0);
 	xl_setup_file(argc,argv);
 
 	return 0;
